"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _ActivitySeasonStatus:
    ValueType = typing.NewType('ValueType', builtins.int)
    V: typing_extensions.TypeAlias = ValueType
class _ActivitySeasonStatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ActivitySeasonStatus.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    StatusNone: _ActivitySeasonStatus.ValueType  # 0
    """"""

    StatusLive: _ActivitySeasonStatus.ValueType  # 1
    """"""

    StatusView: _ActivitySeasonStatus.ValueType  # 2
    """"""

class ActivitySeasonStatus(_ActivitySeasonStatus, metaclass=_ActivitySeasonStatusEnumTypeWrapper):
    """"""
    pass

StatusNone: ActivitySeasonStatus.ValueType  # 0
""""""

StatusLive: ActivitySeasonStatus.ValueType  # 1
""""""

StatusView: ActivitySeasonStatus.ValueType  # 2
""""""

global___ActivitySeasonStatus = ActivitySeasonStatus


class _OrderType:
    ValueType = typing.NewType('ValueType', builtins.int)
    V: typing_extensions.TypeAlias = ValueType
class _OrderTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_OrderType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    TypeNone: _OrderType.ValueType  # 0
    """"""

    TypeOrderActivity: _OrderType.ValueType  # 1
    """"""

    TypeFavSeason: _OrderType.ValueType  # 2
    """"""

    TypeClick: _OrderType.ValueType  # 3
    """"""

class OrderType(_OrderType, metaclass=_OrderTypeEnumTypeWrapper):
    """"""
    pass

TypeNone: OrderType.ValueType  # 0
""""""

TypeOrderActivity: OrderType.ValueType  # 1
""""""

TypeFavSeason: OrderType.ValueType  # 2
""""""

TypeClick: OrderType.ValueType  # 3
""""""

global___OrderType = OrderType


class _ReplyEmoteMetaSize:
    ValueType = typing.NewType('ValueType', builtins.int)
    V: typing_extensions.TypeAlias = ValueType
class _ReplyEmoteMetaSizeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ReplyEmoteMetaSize.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    EMOTE_META_SIZE_UNSPECIFIED: _ReplyEmoteMetaSize.ValueType  # 0
    """"""

    EMOTE_META_SIZE_SMALL: _ReplyEmoteMetaSize.ValueType  # 1
    """"""

    EMOTE_META_SIZE_BIG: _ReplyEmoteMetaSize.ValueType  # 2
    """"""

class ReplyEmoteMetaSize(_ReplyEmoteMetaSize, metaclass=_ReplyEmoteMetaSizeEnumTypeWrapper):
    """"""
    pass

EMOTE_META_SIZE_UNSPECIFIED: ReplyEmoteMetaSize.ValueType  # 0
""""""

EMOTE_META_SIZE_SMALL: ReplyEmoteMetaSize.ValueType  # 1
""""""

EMOTE_META_SIZE_BIG: ReplyEmoteMetaSize.ValueType  # 2
""""""

global___ReplyEmoteMetaSize = ReplyEmoteMetaSize


class AccInfo(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    MID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    SEX_FIELD_NUMBER: builtins.int
    FACE_FIELD_NUMBER: builtins.int
    SIGN_FIELD_NUMBER: builtins.int
    mid: builtins.int
    """"""

    name: typing.Text
    """"""

    sex: typing.Text
    """"""

    face: typing.Text
    """"""

    sign: typing.Text
    """"""

    def __init__(self,
        *,
        mid: builtins.int = ...,
        name: typing.Text = ...,
        sex: typing.Text = ...,
        face: typing.Text = ...,
        sign: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["face",b"face","mid",b"mid","name",b"name","sex",b"sex","sign",b"sign"]) -> None: ...
global___AccInfo = AccInfo

class AccountCard(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    MID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    SEX_FIELD_NUMBER: builtins.int
    RANK_FIELD_NUMBER: builtins.int
    FACE_FIELD_NUMBER: builtins.int
    SPACESTA_FIELD_NUMBER: builtins.int
    SIGN_FIELD_NUMBER: builtins.int
    LEVEL_INFO_FIELD_NUMBER: builtins.int
    PENDANT_FIELD_NUMBER: builtins.int
    NAMEPLATE_FIELD_NUMBER: builtins.int
    OFFICIAL_FIELD_NUMBER: builtins.int
    OFFICIAL_VERIFY_FIELD_NUMBER: builtins.int
    VIP_FIELD_NUMBER: builtins.int
    FANS_FIELD_NUMBER: builtins.int
    FRIEND_FIELD_NUMBER: builtins.int
    ATTENTION_FIELD_NUMBER: builtins.int
    mid: typing.Text
    """"""

    name: typing.Text
    """"""

    sex: typing.Text
    """"""

    rank: typing.Text
    """"""

    face: typing.Text
    """"""

    spacesta: builtins.int
    """"""

    sign: typing.Text
    """"""

    @property
    def level_info(self) -> global___CardLevelInfo:
        """"""
        pass
    @property
    def pendant(self) -> global___PendantInfo:
        """"""
        pass
    @property
    def nameplate(self) -> global___NameplateInfo:
        """"""
        pass
    @property
    def official(self) -> global___OfficialInfo:
        """"""
        pass
    @property
    def official_verify(self) -> global___OfficialVerify:
        """"""
        pass
    @property
    def vip(self) -> global___CardVip:
        """"""
        pass
    fans: builtins.int
    """"""

    friend: builtins.int
    """"""

    attention: builtins.int
    """"""

    def __init__(self,
        *,
        mid: typing.Text = ...,
        name: typing.Text = ...,
        sex: typing.Text = ...,
        rank: typing.Text = ...,
        face: typing.Text = ...,
        spacesta: builtins.int = ...,
        sign: typing.Text = ...,
        level_info: typing.Optional[global___CardLevelInfo] = ...,
        pendant: typing.Optional[global___PendantInfo] = ...,
        nameplate: typing.Optional[global___NameplateInfo] = ...,
        official: typing.Optional[global___OfficialInfo] = ...,
        official_verify: typing.Optional[global___OfficialVerify] = ...,
        vip: typing.Optional[global___CardVip] = ...,
        fans: builtins.int = ...,
        friend: builtins.int = ...,
        attention: builtins.int = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["level_info",b"level_info","nameplate",b"nameplate","official",b"official","official_verify",b"official_verify","pendant",b"pendant","vip",b"vip"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["attention",b"attention","face",b"face","fans",b"fans","friend",b"friend","level_info",b"level_info","mid",b"mid","name",b"name","nameplate",b"nameplate","official",b"official","official_verify",b"official_verify","pendant",b"pendant","rank",b"rank","sex",b"sex","sign",b"sign","spacesta",b"spacesta","vip",b"vip"]) -> None: ...
global___AccountCard = AccountCard

class ActivityArchiveReply(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ARC_FIELD_NUMBER: builtins.int
    BVID_FIELD_NUMBER: builtins.int
    PAGES_FIELD_NUMBER: builtins.int
    REQ_USER_FIELD_NUMBER: builtins.int
    STAFF_FIELD_NUMBER: builtins.int
    RIGHT_RELATE_FIELD_NUMBER: builtins.int
    BOTTOM_RELATE_FIELD_NUMBER: builtins.int
    @property
    def arc(self) -> global___Arc:
        """"""
        pass
    bvid: typing.Text
    """"""

    @property
    def pages(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Page]:
        """"""
        pass
    @property
    def req_user(self) -> global___ReqUser:
        """"""
        pass
    @property
    def staff(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Staff]:
        """"""
        pass
    @property
    def right_relate(self) -> global___OperationRelate:
        """"""
        pass
    @property
    def bottom_relate(self) -> global___OperationRelate:
        """"""
        pass
    def __init__(self,
        *,
        arc: typing.Optional[global___Arc] = ...,
        bvid: typing.Text = ...,
        pages: typing.Optional[typing.Iterable[global___Page]] = ...,
        req_user: typing.Optional[global___ReqUser] = ...,
        staff: typing.Optional[typing.Iterable[global___Staff]] = ...,
        right_relate: typing.Optional[global___OperationRelate] = ...,
        bottom_relate: typing.Optional[global___OperationRelate] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["arc",b"arc","bottom_relate",b"bottom_relate","req_user",b"req_user","right_relate",b"right_relate"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["arc",b"arc","bottom_relate",b"bottom_relate","bvid",b"bvid","pages",b"pages","req_user",b"req_user","right_relate",b"right_relate","staff",b"staff"]) -> None: ...
global___ActivityArchiveReply = ActivityArchiveReply

class ActivityArchiveReq(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    AID_FIELD_NUMBER: builtins.int
    BVID_FIELD_NUMBER: builtins.int
    ACTIVITY_KEY_FIELD_NUMBER: builtins.int
    aid: builtins.int
    """"""

    bvid: typing.Text
    """"""

    activity_key: typing.Text
    """"""

    def __init__(self,
        *,
        aid: builtins.int = ...,
        bvid: typing.Text = ...,
        activity_key: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["activity_key",b"activity_key","aid",b"aid","bvid",b"bvid"]) -> None: ...
global___ActivityArchiveReq = ActivityArchiveReq

class ActivityEpisode(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ID_FIELD_NUMBER: builtins.int
    AID_FIELD_NUMBER: builtins.int
    BVID_FIELD_NUMBER: builtins.int
    CID_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    AUTHOR_FIELD_NUMBER: builtins.int
    RIGHTS_FIELD_NUMBER: builtins.int
    id: builtins.int
    """"""

    aid: builtins.int
    """"""

    bvid: typing.Text
    """"""

    cid: builtins.int
    """"""

    title: typing.Text
    """"""

    cover: typing.Text
    """"""

    @property
    def author(self) -> global___Author:
        """"""
        pass
    @property
    def rights(self) -> global___Rights:
        """"""
        pass
    def __init__(self,
        *,
        id: builtins.int = ...,
        aid: builtins.int = ...,
        bvid: typing.Text = ...,
        cid: builtins.int = ...,
        title: typing.Text = ...,
        cover: typing.Text = ...,
        author: typing.Optional[global___Author] = ...,
        rights: typing.Optional[global___Rights] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["author",b"author","rights",b"rights"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["aid",b"aid","author",b"author","bvid",b"bvid","cid",b"cid","cover",b"cover","id",b"id","rights",b"rights","title",b"title"]) -> None: ...
global___ActivityEpisode = ActivityEpisode

class ActivityGame(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    IFRAMES_FIELD_NUMBER: builtins.int
    DISCLAIMER_FIELD_NUMBER: builtins.int
    DISCLAIMER_URL_FIELD_NUMBER: builtins.int
    @property
    def iframes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ActivityGameIframe]:
        """"""
        pass
    disclaimer: typing.Text
    """"""

    disclaimer_url: typing.Text
    """"""

    def __init__(self,
        *,
        iframes: typing.Optional[typing.Iterable[global___ActivityGameIframe]] = ...,
        disclaimer: typing.Text = ...,
        disclaimer_url: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["disclaimer",b"disclaimer","disclaimer_url",b"disclaimer_url","iframes",b"iframes"]) -> None: ...
global___ActivityGame = ActivityGame

class ActivityGameIframe(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    URL_FIELD_NUMBER: builtins.int
    HEIGHT_FIELD_NUMBER: builtins.int
    url: typing.Text
    """"""

    height: builtins.int
    """"""

    def __init__(self,
        *,
        url: typing.Text = ...,
        height: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["height",b"height","url",b"url"]) -> None: ...
global___ActivityGameIframe = ActivityGameIframe

class ActivityLive(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ROOM_ID_FIELD_NUMBER: builtins.int
    NOW_TIME_FIELD_NUMBER: builtins.int
    START_TIME_FIELD_NUMBER: builtins.int
    END_TIME_FIELD_NUMBER: builtins.int
    HOVER_PIC_FIELD_NUMBER: builtins.int
    HOVER_JUMP_URL_FIELD_NUMBER: builtins.int
    BREAK_CYCLE_FIELD_NUMBER: builtins.int
    TIMELINE_FIELD_NUMBER: builtins.int
    OPERATION_RELATE_FIELD_NUMBER: builtins.int
    REPLY_TYPE_FIELD_NUMBER: builtins.int
    REPLY_ID_FIELD_NUMBER: builtins.int
    HOVER_PIC_CLOSE_FIELD_NUMBER: builtins.int
    GIFT_DISCLAIMER_FIELD_NUMBER: builtins.int
    room_id: builtins.int
    """"""

    now_time: builtins.int
    """"""

    start_time: builtins.int
    """"""

    end_time: builtins.int
    """"""

    hover_pic: typing.Text
    """"""

    hover_jump_url: typing.Text
    """"""

    break_cycle: builtins.int
    """"""

    @property
    def timeline(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___LiveTimeline]:
        """"""
        pass
    @property
    def operation_relate(self) -> global___OperationRelate:
        """"""
        pass
    reply_type: builtins.int
    """"""

    reply_id: builtins.int
    """"""

    hover_pic_close: typing.Text
    """"""

    gift_disclaimer: typing.Text
    """"""

    def __init__(self,
        *,
        room_id: builtins.int = ...,
        now_time: builtins.int = ...,
        start_time: builtins.int = ...,
        end_time: builtins.int = ...,
        hover_pic: typing.Text = ...,
        hover_jump_url: typing.Text = ...,
        break_cycle: builtins.int = ...,
        timeline: typing.Optional[typing.Iterable[global___LiveTimeline]] = ...,
        operation_relate: typing.Optional[global___OperationRelate] = ...,
        reply_type: builtins.int = ...,
        reply_id: builtins.int = ...,
        hover_pic_close: typing.Text = ...,
        gift_disclaimer: typing.Text = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["operation_relate",b"operation_relate"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["break_cycle",b"break_cycle","end_time",b"end_time","gift_disclaimer",b"gift_disclaimer","hover_jump_url",b"hover_jump_url","hover_pic",b"hover_pic","hover_pic_close",b"hover_pic_close","now_time",b"now_time","operation_relate",b"operation_relate","reply_id",b"reply_id","reply_type",b"reply_type","room_id",b"room_id","start_time",b"start_time","timeline",b"timeline"]) -> None: ...
global___ActivityLive = ActivityLive

class ActivityLiveTimeInfoReply(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    NOW_TIME_FIELD_NUMBER: builtins.int
    START_TIME_FIELD_NUMBER: builtins.int
    END_TIME_FIELD_NUMBER: builtins.int
    TIMELINE_FIELD_NUMBER: builtins.int
    now_time: builtins.int
    """"""

    start_time: builtins.int
    """"""

    end_time: builtins.int
    """"""

    @property
    def timeline(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___LiveTimeline]:
        """"""
        pass
    def __init__(self,
        *,
        now_time: builtins.int = ...,
        start_time: builtins.int = ...,
        end_time: builtins.int = ...,
        timeline: typing.Optional[typing.Iterable[global___LiveTimeline]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["end_time",b"end_time","now_time",b"now_time","start_time",b"start_time","timeline",b"timeline"]) -> None: ...
global___ActivityLiveTimeInfoReply = ActivityLiveTimeInfoReply

class ActivityLiveTimeInfoReq(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ACTIVITY_KEY_FIELD_NUMBER: builtins.int
    activity_key: typing.Text
    """"""

    def __init__(self,
        *,
        activity_key: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["activity_key",b"activity_key"]) -> None: ...
global___ActivityLiveTimeInfoReq = ActivityLiveTimeInfoReq

class ActivitySeasonReply(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    STATUS_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    LIVE_FIELD_NUMBER: builtins.int
    SUBSCRIBE_FIELD_NUMBER: builtins.int
    GAME_FIELD_NUMBER: builtins.int
    VIEW_FIELD_NUMBER: builtins.int
    THEME_FIELD_NUMBER: builtins.int
    status: global___ActivitySeasonStatus.ValueType
    """"""

    title: typing.Text
    """"""

    @property
    def live(self) -> global___ActivityLive:
        """"""
        pass
    @property
    def subscribe(self) -> global___ActivitySubscribe:
        """"""
        pass
    @property
    def game(self) -> global___ActivityGame:
        """"""
        pass
    @property
    def view(self) -> global___ActivityView:
        """"""
        pass
    @property
    def theme(self) -> global___ActivityTheme:
        """"""
        pass
    def __init__(self,
        *,
        status: global___ActivitySeasonStatus.ValueType = ...,
        title: typing.Text = ...,
        live: typing.Optional[global___ActivityLive] = ...,
        subscribe: typing.Optional[global___ActivitySubscribe] = ...,
        game: typing.Optional[global___ActivityGame] = ...,
        view: typing.Optional[global___ActivityView] = ...,
        theme: typing.Optional[global___ActivityTheme] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["game",b"game","live",b"live","subscribe",b"subscribe","theme",b"theme","view",b"view"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["game",b"game","live",b"live","status",b"status","subscribe",b"subscribe","theme",b"theme","title",b"title","view",b"view"]) -> None: ...
global___ActivitySeasonReply = ActivitySeasonReply

class ActivitySeasonReq(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    AID_FIELD_NUMBER: builtins.int
    BVID_FIELD_NUMBER: builtins.int
    ACTIVITY_KEY_FIELD_NUMBER: builtins.int
    aid: builtins.int
    """"""

    bvid: typing.Text
    """"""

    activity_key: typing.Text
    """"""

    def __init__(self,
        *,
        aid: builtins.int = ...,
        bvid: typing.Text = ...,
        activity_key: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["activity_key",b"activity_key","aid",b"aid","bvid",b"bvid"]) -> None: ...
global___ActivitySeasonReq = ActivitySeasonReq

class ActivitySeasonSection(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ID_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    EPISODES_FIELD_NUMBER: builtins.int
    id: builtins.int
    """"""

    title: typing.Text
    """"""

    type: builtins.int
    """"""

    @property
    def episodes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ActivityEpisode]:
        """"""
        pass
    def __init__(self,
        *,
        id: builtins.int = ...,
        title: typing.Text = ...,
        type: builtins.int = ...,
        episodes: typing.Optional[typing.Iterable[global___ActivityEpisode]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["episodes",b"episodes","id",b"id","title",b"title","type",b"type"]) -> None: ...
global___ActivitySeasonSection = ActivitySeasonSection

class ActivitySubscribe(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    STATUS_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    BUTTON_TITLE_FIELD_NUMBER: builtins.int
    BUTTON_SELECTED_TITLE_FIELD_NUMBER: builtins.int
    SEASON_STAT_VIEW_FIELD_NUMBER: builtins.int
    SEASON_STAT_DANMAKU_FIELD_NUMBER: builtins.int
    ORDER_TYPE_FIELD_NUMBER: builtins.int
    RESERVE_ACTIVITY_PARAM_FIELD_NUMBER: builtins.int
    FAV_SEASON_PARAM_FIELD_NUMBER: builtins.int
    JUMP_URL_PARAM_FIELD_NUMBER: builtins.int
    status: builtins.bool
    """"""

    title: typing.Text
    """"""

    button_title: typing.Text
    """"""

    button_selected_title: typing.Text
    """"""

    season_stat_view: builtins.int
    """"""

    season_stat_danmaku: builtins.int
    """"""

    order_type: global___OrderType.ValueType
    """"""

    @property
    def reserve_activity_param(self) -> global___ReserveActivityParam:
        """"""
        pass
    @property
    def fav_season_param(self) -> global___FavSeasonParam:
        """"""
        pass
    @property
    def jump_URL_param(self) -> global___JumpURLParam:
        """"""
        pass
    def __init__(self,
        *,
        status: builtins.bool = ...,
        title: typing.Text = ...,
        button_title: typing.Text = ...,
        button_selected_title: typing.Text = ...,
        season_stat_view: builtins.int = ...,
        season_stat_danmaku: builtins.int = ...,
        order_type: global___OrderType.ValueType = ...,
        reserve_activity_param: typing.Optional[global___ReserveActivityParam] = ...,
        fav_season_param: typing.Optional[global___FavSeasonParam] = ...,
        jump_URL_param: typing.Optional[global___JumpURLParam] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["fav_season_param",b"fav_season_param","jump_URL_param",b"jump_URL_param","param",b"param","reserve_activity_param",b"reserve_activity_param"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["button_selected_title",b"button_selected_title","button_title",b"button_title","fav_season_param",b"fav_season_param","jump_URL_param",b"jump_URL_param","order_type",b"order_type","param",b"param","reserve_activity_param",b"reserve_activity_param","season_stat_danmaku",b"season_stat_danmaku","season_stat_view",b"season_stat_view","status",b"status","title",b"title"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["param",b"param"]) -> typing.Optional[typing_extensions.Literal["reserve_activity_param","fav_season_param","jump_URL_param"]]: ...
global___ActivitySubscribe = ActivitySubscribe

class ActivityTheme(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    class KvColorEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor
        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: typing.Text
        value: typing.Text
        def __init__(self,
            *,
            key: typing.Text = ...,
            value: typing.Text = ...,
            ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key",b"key","value",b"value"]) -> None: ...

    BASE_COLOR_FIELD_NUMBER: builtins.int
    LOADING_BG_COLOR_FIELD_NUMBER: builtins.int
    OPERATED_BG_COLOR_FIELD_NUMBER: builtins.int
    DEFAULT_ELEMENT_COLOR_FIELD_NUMBER: builtins.int
    HOVER_ELEMENT_COLOR_FIELD_NUMBER: builtins.int
    SELECTED_ELEMENT_COLOR_FIELD_NUMBER: builtins.int
    BASE_FONT_COLOR_FIELD_NUMBER: builtins.int
    INFO_FONT_COLOR_FIELD_NUMBER: builtins.int
    MASK_BG_COLOR_FIELD_NUMBER: builtins.int
    PAGE_BG_COLOR_FIELD_NUMBER: builtins.int
    CENTER_LOGO_IMG_FIELD_NUMBER: builtins.int
    PAGE_BG_IMG_FIELD_NUMBER: builtins.int
    DECORATIONS2233_IMG_FIELD_NUMBER: builtins.int
    MAIN_BANNER_BG_IMG_FIELD_NUMBER: builtins.int
    MAIN_BANNER_TITLE_IMG_FIELD_NUMBER: builtins.int
    LIKE_ANIMATION_IMG_FIELD_NUMBER: builtins.int
    COMBO_LIKE_IMG_FIELD_NUMBER: builtins.int
    COMBO_COIN_IMG_FIELD_NUMBER: builtins.int
    COMBO_FAV_IMG_FIELD_NUMBER: builtins.int
    ARROW_BTN_IMG_FIELD_NUMBER: builtins.int
    SHARE_ICON_BG_IMG_FIELD_NUMBER: builtins.int
    LIVE_LIST_LOCATION_IMG_FIELD_NUMBER: builtins.int
    LIVE_LIST_LOCATION_IMG_ACTIVE_FIELD_NUMBER: builtins.int
    PLAYER_LOADING_IMG_FIELD_NUMBER: builtins.int
    SHARE_IMG_FIELD_NUMBER: builtins.int
    KV_COLOR_FIELD_NUMBER: builtins.int
    base_color: typing.Text
    """"""

    loading_bg_color: typing.Text
    """"""

    operated_bg_color: typing.Text
    """"""

    default_element_color: typing.Text
    """"""

    hover_element_color: typing.Text
    """"""

    selected_element_color: typing.Text
    """"""

    base_font_color: typing.Text
    """"""

    info_font_color: typing.Text
    """"""

    mask_bg_color: typing.Text
    """"""

    page_bg_color: typing.Text
    """"""

    center_logo_img: typing.Text
    """"""

    page_bg_img: typing.Text
    """"""

    decorations2233_img: typing.Text
    """"""

    main_banner_bg_img: typing.Text
    """"""

    main_banner_title_img: typing.Text
    """"""

    like_animation_img: typing.Text
    """"""

    combo_like_img: typing.Text
    """"""

    combo_coin_img: typing.Text
    """"""

    combo_fav_img: typing.Text
    """"""

    arrow_btn_img: typing.Text
    """"""

    share_icon_bg_img: typing.Text
    """"""

    live_list_location_img: typing.Text
    """"""

    live_list_location_img_active: typing.Text
    """"""

    player_loading_img: typing.Text
    """"""

    share_img: typing.Text
    """"""

    @property
    def kv_color(self) -> google.protobuf.internal.containers.ScalarMap[typing.Text, typing.Text]:
        """"""
        pass
    def __init__(self,
        *,
        base_color: typing.Text = ...,
        loading_bg_color: typing.Text = ...,
        operated_bg_color: typing.Text = ...,
        default_element_color: typing.Text = ...,
        hover_element_color: typing.Text = ...,
        selected_element_color: typing.Text = ...,
        base_font_color: typing.Text = ...,
        info_font_color: typing.Text = ...,
        mask_bg_color: typing.Text = ...,
        page_bg_color: typing.Text = ...,
        center_logo_img: typing.Text = ...,
        page_bg_img: typing.Text = ...,
        decorations2233_img: typing.Text = ...,
        main_banner_bg_img: typing.Text = ...,
        main_banner_title_img: typing.Text = ...,
        like_animation_img: typing.Text = ...,
        combo_like_img: typing.Text = ...,
        combo_coin_img: typing.Text = ...,
        combo_fav_img: typing.Text = ...,
        arrow_btn_img: typing.Text = ...,
        share_icon_bg_img: typing.Text = ...,
        live_list_location_img: typing.Text = ...,
        live_list_location_img_active: typing.Text = ...,
        player_loading_img: typing.Text = ...,
        share_img: typing.Text = ...,
        kv_color: typing.Optional[typing.Mapping[typing.Text, typing.Text]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["arrow_btn_img",b"arrow_btn_img","base_color",b"base_color","base_font_color",b"base_font_color","center_logo_img",b"center_logo_img","combo_coin_img",b"combo_coin_img","combo_fav_img",b"combo_fav_img","combo_like_img",b"combo_like_img","decorations2233_img",b"decorations2233_img","default_element_color",b"default_element_color","hover_element_color",b"hover_element_color","info_font_color",b"info_font_color","kv_color",b"kv_color","like_animation_img",b"like_animation_img","live_list_location_img",b"live_list_location_img","live_list_location_img_active",b"live_list_location_img_active","loading_bg_color",b"loading_bg_color","main_banner_bg_img",b"main_banner_bg_img","main_banner_title_img",b"main_banner_title_img","mask_bg_color",b"mask_bg_color","operated_bg_color",b"operated_bg_color","page_bg_color",b"page_bg_color","page_bg_img",b"page_bg_img","player_loading_img",b"player_loading_img","selected_element_color",b"selected_element_color","share_icon_bg_img",b"share_icon_bg_img","share_img",b"share_img"]) -> None: ...
global___ActivityTheme = ActivityTheme

class ActivityView(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ARC_FIELD_NUMBER: builtins.int
    BVID_FIELD_NUMBER: builtins.int
    PAGES_FIELD_NUMBER: builtins.int
    STAFF_FIELD_NUMBER: builtins.int
    REQ_USER_FIELD_NUMBER: builtins.int
    RIGHT_RELATE_FIELD_NUMBER: builtins.int
    BOTTOM_RELATE_FIELD_NUMBER: builtins.int
    SECTIONS_FIELD_NUMBER: builtins.int
    @property
    def arc(self) -> global___Arc:
        """"""
        pass
    bvid: typing.Text
    """"""

    @property
    def pages(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Page]:
        """"""
        pass
    @property
    def staff(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Staff]:
        """"""
        pass
    @property
    def req_user(self) -> global___ReqUser:
        """"""
        pass
    @property
    def right_relate(self) -> global___OperationRelate:
        """"""
        pass
    @property
    def bottom_relate(self) -> global___OperationRelate:
        """"""
        pass
    @property
    def sections(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ActivitySeasonSection]:
        """"""
        pass
    def __init__(self,
        *,
        arc: typing.Optional[global___Arc] = ...,
        bvid: typing.Text = ...,
        pages: typing.Optional[typing.Iterable[global___Page]] = ...,
        staff: typing.Optional[typing.Iterable[global___Staff]] = ...,
        req_user: typing.Optional[global___ReqUser] = ...,
        right_relate: typing.Optional[global___OperationRelate] = ...,
        bottom_relate: typing.Optional[global___OperationRelate] = ...,
        sections: typing.Optional[typing.Iterable[global___ActivitySeasonSection]] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["arc",b"arc","bottom_relate",b"bottom_relate","req_user",b"req_user","right_relate",b"right_relate"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["arc",b"arc","bottom_relate",b"bottom_relate","bvid",b"bvid","pages",b"pages","req_user",b"req_user","right_relate",b"right_relate","sections",b"sections","staff",b"staff"]) -> None: ...
global___ActivityView = ActivityView

class Arc(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    AID_FIELD_NUMBER: builtins.int
    VIDEOS_FIELD_NUMBER: builtins.int
    TYPE_ID_FIELD_NUMBER: builtins.int
    TYPE_NAME_FIELD_NUMBER: builtins.int
    COPYRIGHT_FIELD_NUMBER: builtins.int
    PIC_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    PUBDATE_FIELD_NUMBER: builtins.int
    CTIME_FIELD_NUMBER: builtins.int
    DESC_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    ACCESS_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    TAG_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    DURATION_FIELD_NUMBER: builtins.int
    MISSION_ID_FIELD_NUMBER: builtins.int
    ORDER_ID_FIELD_NUMBER: builtins.int
    REDIRECT_URL_FIELD_NUMBER: builtins.int
    FORWARD_FIELD_NUMBER: builtins.int
    RIGHTS_FIELD_NUMBER: builtins.int
    AUTHOR_FIELD_NUMBER: builtins.int
    STAT_FIELD_NUMBER: builtins.int
    REPORT_RESULT_FIELD_NUMBER: builtins.int
    DYNAMIC_FIELD_NUMBER: builtins.int
    FIRST_CID_FIELD_NUMBER: builtins.int
    DIMENSION_FIELD_NUMBER: builtins.int
    STAFF_INFO_FIELD_NUMBER: builtins.int
    SEASON_ID_FIELD_NUMBER: builtins.int
    DESC_V2_FIELD_NUMBER: builtins.int
    aid: builtins.int
    """"""

    videos: builtins.int
    """"""

    type_id: builtins.int
    """"""

    type_name: typing.Text
    """"""

    copyright: builtins.int
    """"""

    pic: typing.Text
    """"""

    title: typing.Text
    """"""

    pubdate: builtins.int
    """"""

    ctime: builtins.int
    """"""

    desc: typing.Text
    """"""

    state: builtins.int
    """"""

    access: builtins.int
    """"""

    attribute: builtins.int
    """"""

    tag: typing.Text
    """"""

    @property
    def tags(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[typing.Text]:
        """"""
        pass
    duration: builtins.int
    """"""

    mission_id: builtins.int
    """"""

    order_id: builtins.int
    """"""

    redirect_url: typing.Text
    """"""

    forward: builtins.int
    """"""

    @property
    def rights(self) -> global___Rights:
        """"""
        pass
    @property
    def author(self) -> global___Author:
        """"""
        pass
    @property
    def stat(self) -> global___Stat:
        """"""
        pass
    report_result: typing.Text
    """"""

    dynamic: typing.Text
    """"""

    first_cid: builtins.int
    """"""

    @property
    def dimension(self) -> global___Dimension:
        """"""
        pass
    @property
    def staff_info(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___StaffInfo]:
        """"""
        pass
    season_id: builtins.int
    """"""

    @property
    def desc_v2(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DescV2]:
        """"""
        pass
    def __init__(self,
        *,
        aid: builtins.int = ...,
        videos: builtins.int = ...,
        type_id: builtins.int = ...,
        type_name: typing.Text = ...,
        copyright: builtins.int = ...,
        pic: typing.Text = ...,
        title: typing.Text = ...,
        pubdate: builtins.int = ...,
        ctime: builtins.int = ...,
        desc: typing.Text = ...,
        state: builtins.int = ...,
        access: builtins.int = ...,
        attribute: builtins.int = ...,
        tag: typing.Text = ...,
        tags: typing.Optional[typing.Iterable[typing.Text]] = ...,
        duration: builtins.int = ...,
        mission_id: builtins.int = ...,
        order_id: builtins.int = ...,
        redirect_url: typing.Text = ...,
        forward: builtins.int = ...,
        rights: typing.Optional[global___Rights] = ...,
        author: typing.Optional[global___Author] = ...,
        stat: typing.Optional[global___Stat] = ...,
        report_result: typing.Text = ...,
        dynamic: typing.Text = ...,
        first_cid: builtins.int = ...,
        dimension: typing.Optional[global___Dimension] = ...,
        staff_info: typing.Optional[typing.Iterable[global___StaffInfo]] = ...,
        season_id: builtins.int = ...,
        desc_v2: typing.Optional[typing.Iterable[global___DescV2]] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["author",b"author","dimension",b"dimension","rights",b"rights","stat",b"stat"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["access",b"access","aid",b"aid","attribute",b"attribute","author",b"author","copyright",b"copyright","ctime",b"ctime","desc",b"desc","desc_v2",b"desc_v2","dimension",b"dimension","duration",b"duration","dynamic",b"dynamic","first_cid",b"first_cid","forward",b"forward","mission_id",b"mission_id","order_id",b"order_id","pic",b"pic","pubdate",b"pubdate","redirect_url",b"redirect_url","report_result",b"report_result","rights",b"rights","season_id",b"season_id","staff_info",b"staff_info","stat",b"stat","state",b"state","tag",b"tag","tags",b"tags","title",b"title","type_id",b"type_id","type_name",b"type_name","videos",b"videos"]) -> None: ...
global___Arc = Arc

class Author(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    MID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    FACE_FIELD_NUMBER: builtins.int
    mid: builtins.int
    """"""

    name: typing.Text
    """"""

    face: typing.Text
    """"""

    def __init__(self,
        *,
        mid: builtins.int = ...,
        name: typing.Text = ...,
        face: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["face",b"face","mid",b"mid","name",b"name"]) -> None: ...
global___Author = Author

class Card(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    CARD_FIELD_NUMBER: builtins.int
    SPACE_FIELD_NUMBER: builtins.int
    FOLLOWING_FIELD_NUMBER: builtins.int
    ARCHIVE_COUNT_FIELD_NUMBER: builtins.int
    ARTICLE_COUNT_FIELD_NUMBER: builtins.int
    FOLLOWER_FIELD_NUMBER: builtins.int
    @property
    def card(self) -> global___AccountCard:
        """"""
        pass
    @property
    def space(self) -> global___Space:
        """"""
        pass
    following: builtins.bool
    """"""

    archive_count: builtins.int
    """"""

    article_count: builtins.int
    """"""

    follower: builtins.int
    """"""

    def __init__(self,
        *,
        card: typing.Optional[global___AccountCard] = ...,
        space: typing.Optional[global___Space] = ...,
        following: builtins.bool = ...,
        archive_count: builtins.int = ...,
        article_count: builtins.int = ...,
        follower: builtins.int = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["card",b"card","space",b"space"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["archive_count",b"archive_count","article_count",b"article_count","card",b"card","follower",b"follower","following",b"following","space",b"space"]) -> None: ...
global___Card = Card

class CardLevelInfo(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    CUR_FIELD_NUMBER: builtins.int
    MIN_FIELD_NUMBER: builtins.int
    NOW_EXP_FIELD_NUMBER: builtins.int
    NEXT_EXP_FIELD_NUMBER: builtins.int
    cur: builtins.int
    """"""

    min: builtins.int
    """"""

    now_exp: builtins.int
    """"""

    next_exp: builtins.int
    """"""

    def __init__(self,
        *,
        cur: builtins.int = ...,
        min: builtins.int = ...,
        now_exp: builtins.int = ...,
        next_exp: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cur",b"cur","min",b"min","next_exp",b"next_exp","now_exp",b"now_exp"]) -> None: ...
global___CardLevelInfo = CardLevelInfo

class CardVip(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TYPE_FIELD_NUMBER: builtins.int
    DUE_REMARK_FIELD_NUMBER: builtins.int
    ACCESS_STATUS_FIELD_NUMBER: builtins.int
    VIP_STATUS_FIELD_NUMBER: builtins.int
    VIP_STATUS_WARN_FIELD_NUMBER: builtins.int
    THEME_TYPE_FIELD_NUMBER: builtins.int
    type: builtins.int
    """"""

    due_remark: typing.Text
    """"""

    access_status: builtins.int
    """"""

    vip_status: builtins.int
    """"""

    vip_status_warn: typing.Text
    """"""

    theme_type: builtins.int
    """"""

    def __init__(self,
        *,
        type: builtins.int = ...,
        due_remark: typing.Text = ...,
        access_status: builtins.int = ...,
        vip_status: builtins.int = ...,
        vip_status_warn: typing.Text = ...,
        theme_type: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["access_status",b"access_status","due_remark",b"due_remark","theme_type",b"theme_type","type",b"type","vip_status",b"vip_status","vip_status_warn",b"vip_status_warn"]) -> None: ...
global___CardVip = CardVip

class ClickActivitySeasonReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ORDER_TYPE_FIELD_NUMBER: builtins.int
    RESERVE_ACTIVITY_PARAM_FIELD_NUMBER: builtins.int
    FAV_SEASON_PARAM_FIELD_NUMBER: builtins.int
    JUMP_URL_PARAM_FIELD_NUMBER: builtins.int
    SPMID_FIELD_NUMBER: builtins.int
    ACTION_FIELD_NUMBER: builtins.int
    order_type: global___OrderType.ValueType
    """"""

    @property
    def reserve_activity_param(self) -> global___ReserveActivityParam:
        """"""
        pass
    @property
    def fav_season_param(self) -> global___FavSeasonParam:
        """"""
        pass
    @property
    def jump_URL_param(self) -> global___JumpURLParam:
        """"""
        pass
    spmid: typing.Text
    """"""

    action: builtins.int
    """"""

    def __init__(self,
        *,
        order_type: global___OrderType.ValueType = ...,
        reserve_activity_param: typing.Optional[global___ReserveActivityParam] = ...,
        fav_season_param: typing.Optional[global___FavSeasonParam] = ...,
        jump_URL_param: typing.Optional[global___JumpURLParam] = ...,
        spmid: typing.Text = ...,
        action: builtins.int = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["fav_season_param",b"fav_season_param","jump_URL_param",b"jump_URL_param","param",b"param","reserve_activity_param",b"reserve_activity_param"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["action",b"action","fav_season_param",b"fav_season_param","jump_URL_param",b"jump_URL_param","order_type",b"order_type","param",b"param","reserve_activity_param",b"reserve_activity_param","spmid",b"spmid"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["param",b"param"]) -> typing.Optional[typing_extensions.Literal["reserve_activity_param","fav_season_param","jump_URL_param"]]: ...
global___ClickActivitySeasonReq = ClickActivitySeasonReq

class DescV2(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    RAW_TEXT_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    BIZ_ID_FIELD_NUMBER: builtins.int
    raw_text: typing.Text
    """"""

    type: builtins.int
    """"""

    biz_id: builtins.int
    """"""

    def __init__(self,
        *,
        raw_text: typing.Text = ...,
        type: builtins.int = ...,
        biz_id: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["biz_id",b"biz_id","raw_text",b"raw_text","type",b"type"]) -> None: ...
global___DescV2 = DescV2

class Dimension(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    WIDTH_FIELD_NUMBER: builtins.int
    HEIGHT_FIELD_NUMBER: builtins.int
    ROTATE_FIELD_NUMBER: builtins.int
    width: builtins.int
    """"""

    height: builtins.int
    """"""

    rotate: builtins.int
    """"""

    def __init__(self,
        *,
        width: builtins.int = ...,
        height: builtins.int = ...,
        rotate: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["height",b"height","rotate",b"rotate","width",b"width"]) -> None: ...
global___Dimension = Dimension

class FavSeasonParam(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    SEASON_ID_FIELD_NUMBER: builtins.int
    season_id: builtins.int
    """"""

    def __init__(self,
        *,
        season_id: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["season_id",b"season_id"]) -> None: ...
global___FavSeasonParam = FavSeasonParam

class HotReply(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    PAGE_FIELD_NUMBER: builtins.int
    REPLIES_FIELD_NUMBER: builtins.int
    @property
    def page(self) -> global___ReplyPage:
        """"""
        pass
    @property
    def replies(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Reply]:
        """"""
        pass
    def __init__(self,
        *,
        page: typing.Optional[global___ReplyPage] = ...,
        replies: typing.Optional[typing.Iterable[global___Reply]] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["page",b"page"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["page",b"page","replies",b"replies"]) -> None: ...
global___HotReply = HotReply

class JumpURLParam(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    JUMP_URL_FIELD_NUMBER: builtins.int
    jump_url: typing.Text
    """"""

    def __init__(self,
        *,
        jump_url: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["jump_url",b"jump_url"]) -> None: ...
global___JumpURLParam = JumpURLParam

class LiveTimeline(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    NAME_FIELD_NUMBER: builtins.int
    START_TIME_FIELD_NUMBER: builtins.int
    END_TIME_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    SUBTITLE_FIELD_NUMBER: builtins.int
    H5_COVER_FIELD_NUMBER: builtins.int
    name: typing.Text
    """"""

    start_time: builtins.int
    """"""

    end_time: builtins.int
    """"""

    cover: typing.Text
    """"""

    subtitle: typing.Text
    """"""

    h5_cover: typing.Text
    """"""

    def __init__(self,
        *,
        name: typing.Text = ...,
        start_time: builtins.int = ...,
        end_time: builtins.int = ...,
        cover: typing.Text = ...,
        subtitle: typing.Text = ...,
        h5_cover: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cover",b"cover","end_time",b"end_time","h5_cover",b"h5_cover","name",b"name","start_time",b"start_time","subtitle",b"subtitle"]) -> None: ...
global___LiveTimeline = LiveTimeline

class NameplateInfo(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    NID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    IMAGE_FIELD_NUMBER: builtins.int
    IMAGE_SMALL_FIELD_NUMBER: builtins.int
    LEVEL_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    nid: builtins.int
    """"""

    name: typing.Text
    """"""

    image: typing.Text
    """"""

    image_small: typing.Text
    """"""

    level: typing.Text
    """"""

    condition: typing.Text
    """"""

    def __init__(self,
        *,
        nid: builtins.int = ...,
        name: typing.Text = ...,
        image: typing.Text = ...,
        image_small: typing.Text = ...,
        level: typing.Text = ...,
        condition: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["condition",b"condition","image",b"image","image_small",b"image_small","level",b"level","name",b"name","nid",b"nid"]) -> None: ...
global___NameplateInfo = NameplateInfo

class NoReply(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    def __init__(self,
        ) -> None: ...
global___NoReply = NoReply

class OfficialInfo(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ROLE_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    DESC_FIELD_NUMBER: builtins.int
    role: builtins.int
    """"""

    title: typing.Text
    """"""

    desc: typing.Text
    """"""

    def __init__(self,
        *,
        role: builtins.int = ...,
        title: typing.Text = ...,
        desc: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["desc",b"desc","role",b"role","title",b"title"]) -> None: ...
global___OfficialInfo = OfficialInfo

class OfficialVerify(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TYPE_FIELD_NUMBER: builtins.int
    DESC_FIELD_NUMBER: builtins.int
    type: builtins.int
    """"""

    desc: typing.Text
    """"""

    def __init__(self,
        *,
        type: builtins.int = ...,
        desc: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["desc",b"desc","type",b"type"]) -> None: ...
global___OfficialVerify = OfficialVerify

class OperationRelate(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TITLE_FIELD_NUMBER: builtins.int
    RELATE_ITEM_FIELD_NUMBER: builtins.int
    AI_RELATE_ITEM_FIELD_NUMBER: builtins.int
    title: typing.Text
    """"""

    @property
    def relate_item(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RelateItem]:
        """"""
        pass
    @property
    def ai_relate_item(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Relate]:
        """"""
        pass
    def __init__(self,
        *,
        title: typing.Text = ...,
        relate_item: typing.Optional[typing.Iterable[global___RelateItem]] = ...,
        ai_relate_item: typing.Optional[typing.Iterable[global___Relate]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["ai_relate_item",b"ai_relate_item","relate_item",b"relate_item","title",b"title"]) -> None: ...
global___OperationRelate = OperationRelate

class Page(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    CID_FIELD_NUMBER: builtins.int
    PAGE_FIELD_NUMBER: builtins.int
    FROM_FIELD_NUMBER: builtins.int
    PART_FIELD_NUMBER: builtins.int
    DURATION_FIELD_NUMBER: builtins.int
    VID_FIELD_NUMBER: builtins.int
    DESC_FIELD_NUMBER: builtins.int
    WEBLINK_FIELD_NUMBER: builtins.int
    DIMENSION_FIELD_NUMBER: builtins.int
    cid: builtins.int
    """"""

    page: builtins.int
    """"""

    part: typing.Text
    """"""

    duration: builtins.int
    """"""

    vid: typing.Text
    """"""

    desc: typing.Text
    """"""

    weblink: typing.Text
    """"""

    @property
    def dimension(self) -> global___Dimension:
        """"""
        pass
    def __init__(self,
        *,
        cid: builtins.int = ...,
        page: builtins.int = ...,
        part: typing.Text = ...,
        duration: builtins.int = ...,
        vid: typing.Text = ...,
        desc: typing.Text = ...,
        weblink: typing.Text = ...,
        dimension: typing.Optional[global___Dimension] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["dimension",b"dimension"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cid",b"cid","desc",b"desc","dimension",b"dimension","duration",b"duration","from",b"from","page",b"page","part",b"part","vid",b"vid","weblink",b"weblink"]) -> None: ...
global___Page = Page

class PendantInfo(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    PID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    IMAGE_FIELD_NUMBER: builtins.int
    EXPIRE_FIELD_NUMBER: builtins.int
    pid: builtins.int
    """"""

    name: typing.Text
    """"""

    image: typing.Text
    """"""

    expire: builtins.int
    """"""

    def __init__(self,
        *,
        pid: builtins.int = ...,
        name: typing.Text = ...,
        image: typing.Text = ...,
        expire: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["expire",b"expire","image",b"image","name",b"name","pid",b"pid"]) -> None: ...
global___PendantInfo = PendantInfo

class Relate(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ARC_FIELD_NUMBER: builtins.int
    BVID_FIELD_NUMBER: builtins.int
    SEASON_TYPE_FIELD_NUMBER: builtins.int
    @property
    def arc(self) -> global___Arc:
        """"""
        pass
    bvid: typing.Text
    """"""

    season_type: builtins.int
    """"""

    def __init__(self,
        *,
        arc: typing.Optional[global___Arc] = ...,
        bvid: typing.Text = ...,
        season_type: builtins.int = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["arc",b"arc"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["arc",b"arc","bvid",b"bvid","season_type",b"season_type"]) -> None: ...
global___Relate = Relate

class RelateItem(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    URL_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    url: typing.Text
    """"""

    cover: typing.Text
    """"""

    def __init__(self,
        *,
        url: typing.Text = ...,
        cover: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cover",b"cover","url",b"url"]) -> None: ...
global___RelateItem = RelateItem

class Relation(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    SPECIAL_FIELD_NUMBER: builtins.int
    attribute: builtins.int
    """"""

    special: builtins.int
    """"""

    def __init__(self,
        *,
        attribute: builtins.int = ...,
        special: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["attribute",b"attribute","special",b"special"]) -> None: ...
global___Relation = Relation

class Reply(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    RPID_FIELD_NUMBER: builtins.int
    OID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    MID_FIELD_NUMBER: builtins.int
    ROOT_FIELD_NUMBER: builtins.int
    PARENT_FIELD_NUMBER: builtins.int
    DIALOG_FIELD_NUMBER: builtins.int
    COUNT_FIELD_NUMBER: builtins.int
    RCOUNT_FIELD_NUMBER: builtins.int
    FLOOR_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    FANS_GRADE_FIELD_NUMBER: builtins.int
    ATTR_FIELD_NUMBER: builtins.int
    CTIME_FIELD_NUMBER: builtins.int
    RPID_STR_FIELD_NUMBER: builtins.int
    ROOT_STR_FIELD_NUMBER: builtins.int
    PARENT_STR_FIELD_NUMBER: builtins.int
    DIALOG_STR_FIELD_NUMBER: builtins.int
    LIKE_FIELD_NUMBER: builtins.int
    HATE_FIELD_NUMBER: builtins.int
    ACTION_FIELD_NUMBER: builtins.int
    MEMBER_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    REPLIES_FIELD_NUMBER: builtins.int
    ASSIST_FIELD_NUMBER: builtins.int
    FOLDER_FIELD_NUMBER: builtins.int
    UP_ACTION_FIELD_NUMBER: builtins.int
    LABEL_FIELD_NUMBER: builtins.int
    RAW_INPUT_FIELD_NUMBER: builtins.int
    SHOW_FOLLOW_FIELD_NUMBER: builtins.int
    rpid: builtins.int
    """"""

    oid: builtins.int
    """"""

    type: builtins.int
    """"""

    mid: builtins.int
    """"""

    root: builtins.int
    """"""

    parent: builtins.int
    """"""

    dialog: builtins.int
    """"""

    count: builtins.int
    """"""

    rcount: builtins.int
    """"""

    floor: builtins.int
    """"""

    state: builtins.int
    """"""

    fans_grade: builtins.int
    """"""

    attr: builtins.int
    """"""

    ctime: builtins.int
    """"""

    rpid_str: typing.Text
    """"""

    root_str: typing.Text
    """"""

    parent_str: typing.Text
    """"""

    dialog_str: typing.Text
    """"""

    like: builtins.int
    """"""

    hate: builtins.int
    """"""

    action: builtins.int
    """"""

    @property
    def member(self) -> global___ReplyMember:
        """"""
        pass
    @property
    def content(self) -> global___ReplyContent:
        """"""
        pass
    @property
    def replies(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Reply]:
        """"""
        pass
    assist: builtins.int
    """"""

    @property
    def folder(self) -> global___ReplyFolder:
        """"""
        pass
    @property
    def up_action(self) -> global___ReplyUpAction:
        """"""
        pass
    @property
    def label(self) -> global___ReplyLabel:
        """"""
        pass
    raw_input: typing.Text
    """"""

    show_follow: builtins.bool
    """"""

    def __init__(self,
        *,
        rpid: builtins.int = ...,
        oid: builtins.int = ...,
        type: builtins.int = ...,
        mid: builtins.int = ...,
        root: builtins.int = ...,
        parent: builtins.int = ...,
        dialog: builtins.int = ...,
        count: builtins.int = ...,
        rcount: builtins.int = ...,
        floor: builtins.int = ...,
        state: builtins.int = ...,
        fans_grade: builtins.int = ...,
        attr: builtins.int = ...,
        ctime: builtins.int = ...,
        rpid_str: typing.Text = ...,
        root_str: typing.Text = ...,
        parent_str: typing.Text = ...,
        dialog_str: typing.Text = ...,
        like: builtins.int = ...,
        hate: builtins.int = ...,
        action: builtins.int = ...,
        member: typing.Optional[global___ReplyMember] = ...,
        content: typing.Optional[global___ReplyContent] = ...,
        replies: typing.Optional[typing.Iterable[global___Reply]] = ...,
        assist: builtins.int = ...,
        folder: typing.Optional[global___ReplyFolder] = ...,
        up_action: typing.Optional[global___ReplyUpAction] = ...,
        label: typing.Optional[global___ReplyLabel] = ...,
        raw_input: typing.Text = ...,
        show_follow: builtins.bool = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["content",b"content","folder",b"folder","label",b"label","member",b"member","up_action",b"up_action"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["action",b"action","assist",b"assist","attr",b"attr","content",b"content","count",b"count","ctime",b"ctime","dialog",b"dialog","dialog_str",b"dialog_str","fans_grade",b"fans_grade","floor",b"floor","folder",b"folder","hate",b"hate","label",b"label","like",b"like","member",b"member","mid",b"mid","oid",b"oid","parent",b"parent","parent_str",b"parent_str","raw_input",b"raw_input","rcount",b"rcount","replies",b"replies","root",b"root","root_str",b"root_str","rpid",b"rpid","rpid_str",b"rpid_str","show_follow",b"show_follow","state",b"state","type",b"type","up_action",b"up_action"]) -> None: ...
global___Reply = Reply

class ReplyContent(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    class EmoteEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor
        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: typing.Text
        @property
        def value(self) -> global___ReplyEmote: ...
        def __init__(self,
            *,
            key: typing.Text = ...,
            value: typing.Optional[global___ReplyEmote] = ...,
            ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value",b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key",b"key","value",b"value"]) -> None: ...

    RP_ID_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    VOTE_FIELD_NUMBER: builtins.int
    TOPICS_FIELD_NUMBER: builtins.int
    IP_FIELD_NUMBER: builtins.int
    PLAT_FIELD_NUMBER: builtins.int
    DEVICE_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    MEMBERS_FIELD_NUMBER: builtins.int
    EMOTE_FIELD_NUMBER: builtins.int
    rp_id: builtins.int
    """"""

    message: typing.Text
    """"""

    @property
    def vote(self) -> global___ReplyVote:
        """"""
        pass
    @property
    def topics(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[typing.Text]:
        """"""
        pass
    ip: builtins.int
    """"""

    plat: builtins.int
    """"""

    device: typing.Text
    """"""

    version: typing.Text
    """"""

    @property
    def members(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ReplyMemberInfo]:
        """"""
        pass
    @property
    def emote(self) -> google.protobuf.internal.containers.MessageMap[typing.Text, global___ReplyEmote]:
        """"""
        pass
    def __init__(self,
        *,
        rp_id: builtins.int = ...,
        message: typing.Text = ...,
        vote: typing.Optional[global___ReplyVote] = ...,
        topics: typing.Optional[typing.Iterable[typing.Text]] = ...,
        ip: builtins.int = ...,
        plat: builtins.int = ...,
        device: typing.Text = ...,
        version: typing.Text = ...,
        members: typing.Optional[typing.Iterable[global___ReplyMemberInfo]] = ...,
        emote: typing.Optional[typing.Mapping[typing.Text, global___ReplyEmote]] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["vote",b"vote"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["device",b"device","emote",b"emote","ip",b"ip","members",b"members","message",b"message","plat",b"plat","rp_id",b"rp_id","topics",b"topics","version",b"version","vote",b"vote"]) -> None: ...
global___ReplyContent = ReplyContent

class ReplyEmote(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ID_FIELD_NUMBER: builtins.int
    PACKAGE_ID_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    ATTR_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    META_FIELD_NUMBER: builtins.int
    CTIME_FIELD_NUMBER: builtins.int
    MTIME_FIELD_NUMBER: builtins.int
    id: builtins.int
    """"""

    package_id: builtins.int
    """"""

    state: builtins.int
    """"""

    type: builtins.int
    """"""

    attr: builtins.int
    """"""

    text: typing.Text
    """"""

    url: typing.Text
    """"""

    @property
    def meta(self) -> global___ReplyEmoteMeta:
        """"""
        pass
    ctime: builtins.int
    """"""

    mtime: builtins.int
    """"""

    def __init__(self,
        *,
        id: builtins.int = ...,
        package_id: builtins.int = ...,
        state: builtins.int = ...,
        type: builtins.int = ...,
        attr: builtins.int = ...,
        text: typing.Text = ...,
        url: typing.Text = ...,
        meta: typing.Optional[global___ReplyEmoteMeta] = ...,
        ctime: builtins.int = ...,
        mtime: builtins.int = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["meta",b"meta"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["attr",b"attr","ctime",b"ctime","id",b"id","meta",b"meta","mtime",b"mtime","package_id",b"package_id","state",b"state","text",b"text","type",b"type","url",b"url"]) -> None: ...
global___ReplyEmote = ReplyEmote

class ReplyEmoteMeta(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    SIZE_FIELD_NUMBER: builtins.int
    size: global___ReplyEmoteMetaSize.ValueType
    """"""

    def __init__(self,
        *,
        size: global___ReplyEmoteMetaSize.ValueType = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["size",b"size"]) -> None: ...
global___ReplyEmoteMeta = ReplyEmoteMeta

class ReplyFansDetail(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    UID_FIELD_NUMBER: builtins.int
    MEDAL_ID_FIELD_NUMBER: builtins.int
    MEDAL_NAME_FIELD_NUMBER: builtins.int
    SCORE_FIELD_NUMBER: builtins.int
    LEVEL_FIELD_NUMBER: builtins.int
    INTIMACY_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    RECEIVED_FIELD_NUMBER: builtins.int
    uid: builtins.int
    """"""

    medal_id: builtins.int
    """"""

    medal_name: typing.Text
    """"""

    score: builtins.int
    """"""

    level: builtins.int
    """"""

    intimacy: builtins.int
    """"""

    status: builtins.int
    """"""

    received: builtins.int
    """"""

    def __init__(self,
        *,
        uid: builtins.int = ...,
        medal_id: builtins.int = ...,
        medal_name: typing.Text = ...,
        score: builtins.int = ...,
        level: builtins.int = ...,
        intimacy: builtins.int = ...,
        status: builtins.int = ...,
        received: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["intimacy",b"intimacy","level",b"level","medal_id",b"medal_id","medal_name",b"medal_name","received",b"received","score",b"score","status",b"status","uid",b"uid"]) -> None: ...
global___ReplyFansDetail = ReplyFansDetail

class ReplyFolder(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    HAS_FOLDED_FIELD_NUMBER: builtins.int
    IS_FOLDED_FIELD_NUMBER: builtins.int
    RULE_FIELD_NUMBER: builtins.int
    has_folded: builtins.bool
    """"""

    is_folded: builtins.bool
    """"""

    rule: typing.Text
    """"""

    def __init__(self,
        *,
        has_folded: builtins.bool = ...,
        is_folded: builtins.bool = ...,
        rule: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["has_folded",b"has_folded","is_folded",b"is_folded","rule",b"rule"]) -> None: ...
global___ReplyFolder = ReplyFolder

class ReplyLabel(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    RPID_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    TEXT_COLOR_FIELD_NUMBER: builtins.int
    TEXT_COLOR_NIGHT_MODE_FIELD_NUMBER: builtins.int
    BG_COLOR_FIELD_NUMBER: builtins.int
    BG_COLOR_NIGHT_MODE_FIELD_NUMBER: builtins.int
    LINK_FIELD_NUMBER: builtins.int
    POSITION_FIELD_NUMBER: builtins.int
    rpid: builtins.int
    """"""

    content: typing.Text
    """"""

    text_color: typing.Text
    """"""

    text_color_night_mode: typing.Text
    """"""

    bg_color: typing.Text
    """"""

    bg_color_night_mode: typing.Text
    """"""

    link: typing.Text
    """"""

    position: typing.Text
    """"""

    def __init__(self,
        *,
        rpid: builtins.int = ...,
        content: typing.Text = ...,
        text_color: typing.Text = ...,
        text_color_night_mode: typing.Text = ...,
        bg_color: typing.Text = ...,
        bg_color_night_mode: typing.Text = ...,
        link: typing.Text = ...,
        position: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["bg_color",b"bg_color","bg_color_night_mode",b"bg_color_night_mode","content",b"content","link",b"link","position",b"position","rpid",b"rpid","text_color",b"text_color","text_color_night_mode",b"text_color_night_mode"]) -> None: ...
global___ReplyLabel = ReplyLabel

class ReplyLevelInfo(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    CUR_FIELD_NUMBER: builtins.int
    MIN_FIELD_NUMBER: builtins.int
    NOW_EXP_FIELD_NUMBER: builtins.int
    NEXT_EXP_FIELD_NUMBER: builtins.int
    cur: builtins.int
    """"""

    min: builtins.int
    """"""

    now_exp: builtins.int
    """"""

    next_exp: builtins.int
    """"""

    def __init__(self,
        *,
        cur: builtins.int = ...,
        min: builtins.int = ...,
        now_exp: builtins.int = ...,
        next_exp: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cur",b"cur","min",b"min","next_exp",b"next_exp","now_exp",b"now_exp"]) -> None: ...
global___ReplyLevelInfo = ReplyLevelInfo

class ReplyMember(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    INFO_FIELD_NUMBER: builtins.int
    FANS_DETAIL_FIELD_NUMBER: builtins.int
    FOLLOWING_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___ReplyMemberInfo:
        """"""
        pass
    @property
    def fans_detail(self) -> global___ReplyFansDetail:
        """"""
        pass
    following: builtins.int
    """"""

    def __init__(self,
        *,
        info: typing.Optional[global___ReplyMemberInfo] = ...,
        fans_detail: typing.Optional[global___ReplyFansDetail] = ...,
        following: builtins.int = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["fans_detail",b"fans_detail","info",b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["fans_detail",b"fans_detail","following",b"following","info",b"info"]) -> None: ...
global___ReplyMember = ReplyMember

class ReplyMemberInfo(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ROLE_FIELD_NUMBER: builtins.int
    MID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    SEX_FIELD_NUMBER: builtins.int
    SIGN_FIELD_NUMBER: builtins.int
    AVATAR_FIELD_NUMBER: builtins.int
    RANK_FIELD_NUMBER: builtins.int
    DISPLAY_RANK_FIELD_NUMBER: builtins.int
    LEVEL_INFO_FIELD_NUMBER: builtins.int
    PENDANT_FIELD_NUMBER: builtins.int
    NAMEPLATE_FIELD_NUMBER: builtins.int
    OFFICIAL_VERIFY_FIELD_NUMBER: builtins.int
    VIP_FIELD_NUMBER: builtins.int
    role: builtins.int
    """"""

    mid: typing.Text
    """"""

    name: typing.Text
    """"""

    sex: typing.Text
    """"""

    sign: typing.Text
    """"""

    avatar: typing.Text
    """"""

    rank: typing.Text
    """"""

    display_rank: typing.Text
    """"""

    @property
    def level_info(self) -> global___ReplyLevelInfo:
        """"""
        pass
    @property
    def pendant(self) -> global___PendantInfo:
        """"""
        pass
    @property
    def nameplate(self) -> global___NameplateInfo:
        """"""
        pass
    @property
    def official_verify(self) -> global___OfficialVerify:
        """"""
        pass
    @property
    def vip(self) -> global___ReplyVip:
        """"""
        pass
    def __init__(self,
        *,
        role: builtins.int = ...,
        mid: typing.Text = ...,
        name: typing.Text = ...,
        sex: typing.Text = ...,
        sign: typing.Text = ...,
        avatar: typing.Text = ...,
        rank: typing.Text = ...,
        display_rank: typing.Text = ...,
        level_info: typing.Optional[global___ReplyLevelInfo] = ...,
        pendant: typing.Optional[global___PendantInfo] = ...,
        nameplate: typing.Optional[global___NameplateInfo] = ...,
        official_verify: typing.Optional[global___OfficialVerify] = ...,
        vip: typing.Optional[global___ReplyVip] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["level_info",b"level_info","nameplate",b"nameplate","official_verify",b"official_verify","pendant",b"pendant","vip",b"vip"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["avatar",b"avatar","display_rank",b"display_rank","level_info",b"level_info","mid",b"mid","name",b"name","nameplate",b"nameplate","official_verify",b"official_verify","pendant",b"pendant","rank",b"rank","role",b"role","sex",b"sex","sign",b"sign","vip",b"vip"]) -> None: ...
global___ReplyMemberInfo = ReplyMemberInfo

class ReplyPage(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ACOUNT_FIELD_NUMBER: builtins.int
    COUNT_FIELD_NUMBER: builtins.int
    NUM_FIELD_NUMBER: builtins.int
    SIZE_FIELD_NUMBER: builtins.int
    acount: builtins.int
    """"""

    count: builtins.int
    """"""

    num: builtins.int
    """"""

    size: builtins.int
    """"""

    def __init__(self,
        *,
        acount: builtins.int = ...,
        count: builtins.int = ...,
        num: builtins.int = ...,
        size: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["acount",b"acount","count",b"count","num",b"num","size",b"size"]) -> None: ...
global___ReplyPage = ReplyPage

class ReplyUpAction(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    LIKE_FIELD_NUMBER: builtins.int
    REPLY_FIELD_NUMBER: builtins.int
    like: builtins.bool
    """"""

    reply: builtins.bool
    """"""

    def __init__(self,
        *,
        like: builtins.bool = ...,
        reply: builtins.bool = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["like",b"like","reply",b"reply"]) -> None: ...
global___ReplyUpAction = ReplyUpAction

class ReplyVip(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TYPE_FIELD_NUMBER: builtins.int
    DUE_DATE_FIELD_NUMBER: builtins.int
    DUE_REMARK_FIELD_NUMBER: builtins.int
    ACCESS_STATUS_FIELD_NUMBER: builtins.int
    VIP_STATUS_FIELD_NUMBER: builtins.int
    VIP_STATUS_WARN_FIELD_NUMBER: builtins.int
    THEME_TYPE_FIELD_NUMBER: builtins.int
    LABEL_FIELD_NUMBER: builtins.int
    type: builtins.int
    """"""

    due_date: builtins.int
    """"""

    due_remark: typing.Text
    """"""

    access_status: builtins.int
    """"""

    vip_status: builtins.int
    """"""

    vip_status_warn: typing.Text
    """"""

    theme_type: builtins.int
    """"""

    @property
    def label(self) -> global___VipLabel:
        """"""
        pass
    def __init__(self,
        *,
        type: builtins.int = ...,
        due_date: builtins.int = ...,
        due_remark: typing.Text = ...,
        access_status: builtins.int = ...,
        vip_status: builtins.int = ...,
        vip_status_warn: typing.Text = ...,
        theme_type: builtins.int = ...,
        label: typing.Optional[global___VipLabel] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["label",b"label"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["access_status",b"access_status","due_date",b"due_date","due_remark",b"due_remark","label",b"label","theme_type",b"theme_type","type",b"type","vip_status",b"vip_status","vip_status_warn",b"vip_status_warn"]) -> None: ...
global___ReplyVip = ReplyVip

class ReplyVote(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ID_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    CNT_FIELD_NUMBER: builtins.int
    DESC_FIELD_NUMBER: builtins.int
    DELETED_FIELD_NUMBER: builtins.int
    id: builtins.int
    """"""

    title: typing.Text
    """"""

    cnt: builtins.int
    """"""

    desc: typing.Text
    """"""

    deleted: builtins.bool
    """"""

    def __init__(self,
        *,
        id: builtins.int = ...,
        title: typing.Text = ...,
        cnt: builtins.int = ...,
        desc: typing.Text = ...,
        deleted: builtins.bool = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cnt",b"cnt","deleted",b"deleted","desc",b"desc","id",b"id","title",b"title"]) -> None: ...
global___ReplyVote = ReplyVote

class ReqUser(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    FAVORITE_FIELD_NUMBER: builtins.int
    LIKE_FIELD_NUMBER: builtins.int
    DISLIKE_FIELD_NUMBER: builtins.int
    MULTIPLY_FIELD_NUMBER: builtins.int
    favorite: builtins.bool
    """"""

    like: builtins.bool
    """"""

    dislike: builtins.bool
    """"""

    multiply: builtins.int
    """"""

    def __init__(self,
        *,
        favorite: builtins.bool = ...,
        like: builtins.bool = ...,
        dislike: builtins.bool = ...,
        multiply: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["dislike",b"dislike","favorite",b"favorite","like",b"like","multiply",b"multiply"]) -> None: ...
global___ReqUser = ReqUser

class ReserveActivityParam(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    RESERVE_ID_FIELD_NUMBER: builtins.int
    FROM_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    OID_FIELD_NUMBER: builtins.int
    reserve_id: builtins.int
    """"""

    type: typing.Text
    """"""

    oid: builtins.int
    """"""

    def __init__(self,
        *,
        reserve_id: builtins.int = ...,
        type: typing.Text = ...,
        oid: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["from",b"from","oid",b"oid","reserve_id",b"reserve_id","type",b"type"]) -> None: ...
global___ReserveActivityParam = ReserveActivityParam

class Rights(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    BP_FIELD_NUMBER: builtins.int
    ELEC_FIELD_NUMBER: builtins.int
    DOWNLOAD_FIELD_NUMBER: builtins.int
    MOVIE_FIELD_NUMBER: builtins.int
    PAY_FIELD_NUMBER: builtins.int
    HD5_FIELD_NUMBER: builtins.int
    NO_REPRINT_FIELD_NUMBER: builtins.int
    AUTOPLAY_FIELD_NUMBER: builtins.int
    UGC_PAY_FIELD_NUMBER: builtins.int
    IS_COOPERATION_FIELD_NUMBER: builtins.int
    UGC_PAY_PREVIEW_FIELD_NUMBER: builtins.int
    bp: builtins.int
    """"""

    elec: builtins.int
    """"""

    download: builtins.int
    """"""

    movie: builtins.int
    """"""

    pay: builtins.int
    """"""

    hd5: builtins.int
    """"""

    no_reprint: builtins.int
    """"""

    autoplay: builtins.int
    """"""

    ugc_pay: builtins.int
    """"""

    is_cooperation: builtins.int
    """"""

    ugc_pay_preview: builtins.int
    """"""

    def __init__(self,
        *,
        bp: builtins.int = ...,
        elec: builtins.int = ...,
        download: builtins.int = ...,
        movie: builtins.int = ...,
        pay: builtins.int = ...,
        hd5: builtins.int = ...,
        no_reprint: builtins.int = ...,
        autoplay: builtins.int = ...,
        ugc_pay: builtins.int = ...,
        is_cooperation: builtins.int = ...,
        ugc_pay_preview: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["autoplay",b"autoplay","bp",b"bp","download",b"download","elec",b"elec","hd5",b"hd5","is_cooperation",b"is_cooperation","movie",b"movie","no_reprint",b"no_reprint","pay",b"pay","ugc_pay",b"ugc_pay","ugc_pay_preview",b"ugc_pay_preview"]) -> None: ...
global___Rights = Rights

class SeasonEpisode(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    SEASON_ID_FIELD_NUMBER: builtins.int
    SECTION_ID_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    AID_FIELD_NUMBER: builtins.int
    CID_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ARC_FIELD_NUMBER: builtins.int
    PAGE_FIELD_NUMBER: builtins.int
    BVID_FIELD_NUMBER: builtins.int
    season_id: builtins.int
    """"""

    section_id: builtins.int
    """"""

    id: builtins.int
    """"""

    aid: builtins.int
    """"""

    cid: builtins.int
    """"""

    title: typing.Text
    """"""

    attribute: builtins.int
    """"""

    @property
    def arc(self) -> global___Arc:
        """"""
        pass
    @property
    def page(self) -> global___Page:
        """"""
        pass
    bvid: typing.Text
    """"""

    def __init__(self,
        *,
        season_id: builtins.int = ...,
        section_id: builtins.int = ...,
        id: builtins.int = ...,
        aid: builtins.int = ...,
        cid: builtins.int = ...,
        title: typing.Text = ...,
        attribute: builtins.int = ...,
        arc: typing.Optional[global___Arc] = ...,
        page: typing.Optional[global___Page] = ...,
        bvid: typing.Text = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["arc",b"arc","page",b"page"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["aid",b"aid","arc",b"arc","attribute",b"attribute","bvid",b"bvid","cid",b"cid","id",b"id","page",b"page","season_id",b"season_id","section_id",b"section_id","title",b"title"]) -> None: ...
global___SeasonEpisode = SeasonEpisode

class SeasonSection(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    SEASON_ID_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    EPISODES_FIELD_NUMBER: builtins.int
    season_id: builtins.int
    """"""

    id: builtins.int
    """"""

    title: typing.Text
    """"""

    type: builtins.int
    """"""

    @property
    def episodes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SeasonEpisode]:
        """"""
        pass
    def __init__(self,
        *,
        season_id: builtins.int = ...,
        id: builtins.int = ...,
        title: typing.Text = ...,
        type: builtins.int = ...,
        episodes: typing.Optional[typing.Iterable[global___SeasonEpisode]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["episodes",b"episodes","id",b"id","season_id",b"season_id","title",b"title","type",b"type"]) -> None: ...
global___SeasonSection = SeasonSection

class SeasonStat(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    SEASON_ID_FIELD_NUMBER: builtins.int
    VIEW_FIELD_NUMBER: builtins.int
    DANMAKU_FIELD_NUMBER: builtins.int
    REPLY_FIELD_NUMBER: builtins.int
    FAV_FIELD_NUMBER: builtins.int
    COIN_FIELD_NUMBER: builtins.int
    SHARE_FIELD_NUMBER: builtins.int
    NOW_RANK_FIELD_NUMBER: builtins.int
    HIS_RANK_FIELD_NUMBER: builtins.int
    LIKE_FIELD_NUMBER: builtins.int
    season_id: builtins.int
    """"""

    view: builtins.int
    """"""

    danmaku: builtins.int
    """"""

    reply: builtins.int
    """"""

    fav: builtins.int
    """"""

    coin: builtins.int
    """"""

    share: builtins.int
    """"""

    now_rank: builtins.int
    """"""

    his_rank: builtins.int
    """"""

    like: builtins.int
    """"""

    def __init__(self,
        *,
        season_id: builtins.int = ...,
        view: builtins.int = ...,
        danmaku: builtins.int = ...,
        reply: builtins.int = ...,
        fav: builtins.int = ...,
        coin: builtins.int = ...,
        share: builtins.int = ...,
        now_rank: builtins.int = ...,
        his_rank: builtins.int = ...,
        like: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["coin",b"coin","danmaku",b"danmaku","fav",b"fav","his_rank",b"his_rank","like",b"like","now_rank",b"now_rank","reply",b"reply","season_id",b"season_id","share",b"share","view",b"view"]) -> None: ...
global___SeasonStat = SeasonStat

class Space(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    S_IMG_FIELD_NUMBER: builtins.int
    L_IMG_FIELD_NUMBER: builtins.int
    s_img: typing.Text
    """"""

    l_img: typing.Text
    """"""

    def __init__(self,
        *,
        s_img: typing.Text = ...,
        l_img: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["l_img",b"l_img","s_img",b"s_img"]) -> None: ...
global___Space = Space

class Staff(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    MID_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    FACE_FIELD_NUMBER: builtins.int
    VIP_FIELD_NUMBER: builtins.int
    OFFICIAL_FIELD_NUMBER: builtins.int
    FOLLOWER_FIELD_NUMBER: builtins.int
    LABEL_STYLE_FIELD_NUMBER: builtins.int
    RELATION_FIELD_NUMBER: builtins.int
    mid: builtins.int
    """"""

    title: typing.Text
    """"""

    name: typing.Text
    """"""

    face: typing.Text
    """"""

    @property
    def vip(self) -> global___VipInfo:
        """"""
        pass
    @property
    def official(self) -> global___OfficialInfo:
        """"""
        pass
    follower: builtins.int
    """"""

    label_style: builtins.int
    """"""

    @property
    def relation(self) -> global___Relation:
        """"""
        pass
    def __init__(self,
        *,
        mid: builtins.int = ...,
        title: typing.Text = ...,
        name: typing.Text = ...,
        face: typing.Text = ...,
        vip: typing.Optional[global___VipInfo] = ...,
        official: typing.Optional[global___OfficialInfo] = ...,
        follower: builtins.int = ...,
        label_style: builtins.int = ...,
        relation: typing.Optional[global___Relation] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["official",b"official","relation",b"relation","vip",b"vip"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["face",b"face","follower",b"follower","label_style",b"label_style","mid",b"mid","name",b"name","official",b"official","relation",b"relation","title",b"title","vip",b"vip"]) -> None: ...
global___Staff = Staff

class StaffInfo(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    MID_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    mid: builtins.int
    """"""

    title: typing.Text
    """"""

    def __init__(self,
        *,
        mid: builtins.int = ...,
        title: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["mid",b"mid","title",b"title"]) -> None: ...
global___StaffInfo = StaffInfo

class Stat(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    AID_FIELD_NUMBER: builtins.int
    VIEW_FIELD_NUMBER: builtins.int
    DANMAKU_FIELD_NUMBER: builtins.int
    REPLY_FIELD_NUMBER: builtins.int
    FAV_FIELD_NUMBER: builtins.int
    COIN_FIELD_NUMBER: builtins.int
    SHARE_FIELD_NUMBER: builtins.int
    NOW_RANK_FIELD_NUMBER: builtins.int
    HIS_RANK_FIELD_NUMBER: builtins.int
    LIKE_FIELD_NUMBER: builtins.int
    DISLIKE_FIELD_NUMBER: builtins.int
    EVALUATION_FIELD_NUMBER: builtins.int
    ARGUE_MSG_FIELD_NUMBER: builtins.int
    aid: builtins.int
    """"""

    view: builtins.int
    """"""

    danmaku: builtins.int
    """"""

    reply: builtins.int
    """"""

    fav: builtins.int
    """"""

    coin: builtins.int
    """"""

    share: builtins.int
    """"""

    now_rank: builtins.int
    """"""

    his_rank: builtins.int
    """"""

    like: builtins.int
    """"""

    dislike: builtins.int
    """"""

    evaluation: typing.Text
    """"""

    argue_msg: typing.Text
    """"""

    def __init__(self,
        *,
        aid: builtins.int = ...,
        view: builtins.int = ...,
        danmaku: builtins.int = ...,
        reply: builtins.int = ...,
        fav: builtins.int = ...,
        coin: builtins.int = ...,
        share: builtins.int = ...,
        now_rank: builtins.int = ...,
        his_rank: builtins.int = ...,
        like: builtins.int = ...,
        dislike: builtins.int = ...,
        evaluation: typing.Text = ...,
        argue_msg: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["aid",b"aid","argue_msg",b"argue_msg","coin",b"coin","danmaku",b"danmaku","dislike",b"dislike","evaluation",b"evaluation","fav",b"fav","his_rank",b"his_rank","like",b"like","now_rank",b"now_rank","reply",b"reply","share",b"share","view",b"view"]) -> None: ...
global___Stat = Stat

class Subtitle(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ALLOW_SUBMIT_FIELD_NUMBER: builtins.int
    LIST_FIELD_NUMBER: builtins.int
    allow_submit: builtins.bool
    """"""

    @property
    def list(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SubtitleItem]:
        """"""
        pass
    def __init__(self,
        *,
        allow_submit: builtins.bool = ...,
        list: typing.Optional[typing.Iterable[global___SubtitleItem]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["allow_submit",b"allow_submit","list",b"list"]) -> None: ...
global___Subtitle = Subtitle

class SubtitleItem(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ID_FIELD_NUMBER: builtins.int
    LAN_FIELD_NUMBER: builtins.int
    LAN_DOC_FIELD_NUMBER: builtins.int
    IS_LOCK_FIELD_NUMBER: builtins.int
    AUTHOR_MID_FIELD_NUMBER: builtins.int
    SUBTITLE_URL_FIELD_NUMBER: builtins.int
    AUTHOR_FIELD_NUMBER: builtins.int
    id: builtins.int
    """"""

    lan: typing.Text
    """"""

    lan_doc: typing.Text
    """"""

    is_lock: builtins.bool
    """"""

    author_mid: builtins.int
    """"""

    subtitle_url: typing.Text
    """"""

    @property
    def author(self) -> global___AccInfo:
        """"""
        pass
    def __init__(self,
        *,
        id: builtins.int = ...,
        lan: typing.Text = ...,
        lan_doc: typing.Text = ...,
        is_lock: builtins.bool = ...,
        author_mid: builtins.int = ...,
        subtitle_url: typing.Text = ...,
        author: typing.Optional[global___AccInfo] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["author",b"author"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["author",b"author","author_mid",b"author_mid","id",b"id","is_lock",b"is_lock","lan",b"lan","lan_doc",b"lan_doc","subtitle_url",b"subtitle_url"]) -> None: ...
global___SubtitleItem = SubtitleItem

class Tag(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    HEAD_COVER_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    SHORT_CONTENT_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    CTIME_FIELD_NUMBER: builtins.int
    TAG_COUNT_FIELD_NUMBER: builtins.int
    IS_ATTEN_FIELD_NUMBER: builtins.int
    LIKES_FIELD_NUMBER: builtins.int
    HATES_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    LIKED_FIELD_NUMBER: builtins.int
    HATED_FIELD_NUMBER: builtins.int
    id: builtins.int
    """"""

    name: typing.Text
    """"""

    cover: typing.Text
    """"""

    head_cover: typing.Text
    """"""

    content: typing.Text
    """"""

    short_content: typing.Text
    """"""

    type: builtins.int
    """"""

    state: builtins.int
    """"""

    ctime: builtins.int
    """"""

    @property
    def tag_count(self) -> global___TagCount:
        """"""
        pass
    is_atten: builtins.int
    """"""

    likes: builtins.int
    """"""

    hates: builtins.int
    """"""

    attribute: builtins.int
    """"""

    liked: builtins.int
    """"""

    hated: builtins.int
    """"""

    def __init__(self,
        *,
        id: builtins.int = ...,
        name: typing.Text = ...,
        cover: typing.Text = ...,
        head_cover: typing.Text = ...,
        content: typing.Text = ...,
        short_content: typing.Text = ...,
        type: builtins.int = ...,
        state: builtins.int = ...,
        ctime: builtins.int = ...,
        tag_count: typing.Optional[global___TagCount] = ...,
        is_atten: builtins.int = ...,
        likes: builtins.int = ...,
        hates: builtins.int = ...,
        attribute: builtins.int = ...,
        liked: builtins.int = ...,
        hated: builtins.int = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["tag_count",b"tag_count"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["attribute",b"attribute","content",b"content","cover",b"cover","ctime",b"ctime","hated",b"hated","hates",b"hates","head_cover",b"head_cover","id",b"id","is_atten",b"is_atten","liked",b"liked","likes",b"likes","name",b"name","short_content",b"short_content","state",b"state","tag_count",b"tag_count","type",b"type"]) -> None: ...
global___Tag = Tag

class TagCount(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    VIEW_FIELD_NUMBER: builtins.int
    USE_FIELD_NUMBER: builtins.int
    ATTEN_FIELD_NUMBER: builtins.int
    view: builtins.int
    """"""

    use: builtins.int
    """"""

    atten: builtins.int
    """"""

    def __init__(self,
        *,
        view: builtins.int = ...,
        use: builtins.int = ...,
        atten: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["atten",b"atten","use",b"use","view",b"view"]) -> None: ...
global___TagCount = TagCount

class UGCPayAsset(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    class PlatformPriceEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor
        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: typing.Text
        value: builtins.int
        def __init__(self,
            *,
            key: typing.Text = ...,
            value: builtins.int = ...,
            ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key",b"key","value",b"value"]) -> None: ...

    PRICE_FIELD_NUMBER: builtins.int
    PLATFORM_PRICE_FIELD_NUMBER: builtins.int
    price: builtins.int
    """"""

    @property
    def platform_price(self) -> google.protobuf.internal.containers.ScalarMap[typing.Text, builtins.int]:
        """"""
        pass
    def __init__(self,
        *,
        price: builtins.int = ...,
        platform_price: typing.Optional[typing.Mapping[typing.Text, builtins.int]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["platform_price",b"platform_price","price",b"price"]) -> None: ...
global___UGCPayAsset = UGCPayAsset

class UGCSeason(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ID_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    MID_FIELD_NUMBER: builtins.int
    INTRO_FIELD_NUMBER: builtins.int
    SIGN_STATE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    SECTIONS_FIELD_NUMBER: builtins.int
    STAT_FIELD_NUMBER: builtins.int
    EP_COUNT_FIELD_NUMBER: builtins.int
    SEASON_TYPE_FIELD_NUMBER: builtins.int
    id: builtins.int
    """"""

    title: typing.Text
    """"""

    cover: typing.Text
    """"""

    mid: builtins.int
    """"""

    intro: typing.Text
    """"""

    sign_state: builtins.int
    """"""

    attribute: builtins.int
    """"""

    @property
    def sections(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SeasonSection]:
        """"""
        pass
    @property
    def stat(self) -> global___SeasonStat:
        """"""
        pass
    ep_count: builtins.int
    """"""

    season_type: builtins.int
    """"""

    def __init__(self,
        *,
        id: builtins.int = ...,
        title: typing.Text = ...,
        cover: typing.Text = ...,
        mid: builtins.int = ...,
        intro: typing.Text = ...,
        sign_state: builtins.int = ...,
        attribute: builtins.int = ...,
        sections: typing.Optional[typing.Iterable[global___SeasonSection]] = ...,
        stat: typing.Optional[global___SeasonStat] = ...,
        ep_count: builtins.int = ...,
        season_type: builtins.int = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["stat",b"stat"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["attribute",b"attribute","cover",b"cover","ep_count",b"ep_count","id",b"id","intro",b"intro","mid",b"mid","season_type",b"season_type","sections",b"sections","sign_state",b"sign_state","stat",b"stat","title",b"title"]) -> None: ...
global___UGCSeason = UGCSeason

class View(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ARC_FIELD_NUMBER: builtins.int
    NO_CACHE_FIELD_NUMBER: builtins.int
    PAGES_FIELD_NUMBER: builtins.int
    SUBTITLE_FIELD_NUMBER: builtins.int
    ASSET_FIELD_NUMBER: builtins.int
    LABEL_FIELD_NUMBER: builtins.int
    STAFF_FIELD_NUMBER: builtins.int
    UGC_SEASON_FIELD_NUMBER: builtins.int
    STEIN_GUIDE_CID_FIELD_NUMBER: builtins.int
    @property
    def arc(self) -> global___Arc:
        """"""
        pass
    no_cache: builtins.bool
    """"""

    @property
    def pages(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Page]:
        """"""
        pass
    @property
    def subtitle(self) -> global___Subtitle:
        """"""
        pass
    @property
    def asset(self) -> global___UGCPayAsset:
        """"""
        pass
    @property
    def label(self) -> global___ViewLabel:
        """"""
        pass
    @property
    def staff(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Staff]:
        """"""
        pass
    @property
    def ugc_season(self) -> global___UGCSeason:
        """"""
        pass
    stein_guide_cid: builtins.int
    """"""

    def __init__(self,
        *,
        arc: typing.Optional[global___Arc] = ...,
        no_cache: builtins.bool = ...,
        pages: typing.Optional[typing.Iterable[global___Page]] = ...,
        subtitle: typing.Optional[global___Subtitle] = ...,
        asset: typing.Optional[global___UGCPayAsset] = ...,
        label: typing.Optional[global___ViewLabel] = ...,
        staff: typing.Optional[typing.Iterable[global___Staff]] = ...,
        ugc_season: typing.Optional[global___UGCSeason] = ...,
        stein_guide_cid: builtins.int = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["arc",b"arc","asset",b"asset","label",b"label","subtitle",b"subtitle","ugc_season",b"ugc_season"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["arc",b"arc","asset",b"asset","label",b"label","no_cache",b"no_cache","pages",b"pages","staff",b"staff","stein_guide_cid",b"stein_guide_cid","subtitle",b"subtitle","ugc_season",b"ugc_season"]) -> None: ...
global___View = View

class ViewDetailReply(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    VIEW_FIELD_NUMBER: builtins.int
    CARD_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    REPLY_FIELD_NUMBER: builtins.int
    RELATED_FIELD_NUMBER: builtins.int
    @property
    def view(self) -> global___View:
        """"""
        pass
    @property
    def card(self) -> global___Card:
        """"""
        pass
    @property
    def tags(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Tag]:
        """"""
        pass
    @property
    def reply(self) -> global___HotReply:
        """"""
        pass
    @property
    def related(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Arc]:
        """"""
        pass
    def __init__(self,
        *,
        view: typing.Optional[global___View] = ...,
        card: typing.Optional[global___Card] = ...,
        tags: typing.Optional[typing.Iterable[global___Tag]] = ...,
        reply: typing.Optional[global___HotReply] = ...,
        related: typing.Optional[typing.Iterable[global___Arc]] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["card",b"card","reply",b"reply","view",b"view"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["card",b"card","related",b"related","reply",b"reply","tags",b"tags","view",b"view"]) -> None: ...
global___ViewDetailReply = ViewDetailReply

class ViewDetailReq(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    AID_FIELD_NUMBER: builtins.int
    BVID_FIELD_NUMBER: builtins.int
    aid: builtins.int
    """"""

    bvid: typing.Text
    """"""

    def __init__(self,
        *,
        aid: builtins.int = ...,
        bvid: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["aid",b"aid","bvid",b"bvid"]) -> None: ...
global___ViewDetailReq = ViewDetailReq

class ViewLabel(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TYPE_FIELD_NUMBER: builtins.int
    type: builtins.int
    """"""

    def __init__(self,
        *,
        type: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["type",b"type"]) -> None: ...
global___ViewLabel = ViewLabel

class VipInfo(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TYPE_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    VIP_PAY_TYPE_FIELD_NUMBER: builtins.int
    THEME_TYPE_FIELD_NUMBER: builtins.int
    type: builtins.int
    """"""

    status: builtins.int
    """"""

    vip_pay_type: builtins.int
    """"""

    theme_type: builtins.int
    """"""

    def __init__(self,
        *,
        type: builtins.int = ...,
        status: builtins.int = ...,
        vip_pay_type: builtins.int = ...,
        theme_type: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["status",b"status","theme_type",b"theme_type","type",b"type","vip_pay_type",b"vip_pay_type"]) -> None: ...
global___VipInfo = VipInfo

class VipLabel(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    PATH_FIELD_NUMBER: builtins.int
    path: typing.Text
    """"""

    def __init__(self,
        *,
        path: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["path",b"path"]) -> None: ...
global___VipLabel = VipLabel



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from bilireq.grpc.protos.bilibili.dynamic.common import dynamic_pb2 as bilibili_dot_dynamic_dot_common_dot_dynamic__pb2
from bilireq.grpc.protos.bilibili.dynamic.interfaces.feed.v1 import api_pb2 as bilibili_dot_dynamic_dot_interfaces_dot_feed_dot_v1_dot_api__pb2


class FeedStub(object):
    """
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateInitCheck = channel.unary_unary(
                '/bilibili.main.dynamic.feed.v1.Feed/CreateInitCheck',
                request_serializer=bilibili_dot_dynamic_dot_interfaces_dot_feed_dot_v1_dot_api__pb2.CreateInitCheckReq.SerializeToString,
                response_deserializer=bilibili_dot_dynamic_dot_common_dot_dynamic__pb2.CreateCheckResp.FromString,
                )
        self.SubmitCheck = channel.unary_unary(
                '/bilibili.main.dynamic.feed.v1.Feed/SubmitCheck',
                request_serializer=bilibili_dot_dynamic_dot_interfaces_dot_feed_dot_v1_dot_api__pb2.SubmitCheckReq.SerializeToString,
                response_deserializer=bilibili_dot_dynamic_dot_interfaces_dot_feed_dot_v1_dot_api__pb2.SubmitCheckRsp.FromString,
                )
        self.CreateDyn = channel.unary_unary(
                '/bilibili.main.dynamic.feed.v1.Feed/CreateDyn',
                request_serializer=bilibili_dot_dynamic_dot_interfaces_dot_feed_dot_v1_dot_api__pb2.CreateDynReq.SerializeToString,
                response_deserializer=bilibili_dot_dynamic_dot_common_dot_dynamic__pb2.CreateResp.FromString,
                )
        self.GetUidByName = channel.unary_unary(
                '/bilibili.main.dynamic.feed.v1.Feed/GetUidByName',
                request_serializer=bilibili_dot_dynamic_dot_common_dot_dynamic__pb2.GetUidByNameReq.SerializeToString,
                response_deserializer=bilibili_dot_dynamic_dot_common_dot_dynamic__pb2.GetUidByNameRsp.FromString,
                )
        self.AtList = channel.unary_unary(
                '/bilibili.main.dynamic.feed.v1.Feed/AtList',
                request_serializer=bilibili_dot_dynamic_dot_common_dot_dynamic__pb2.AtListReq.SerializeToString,
                response_deserializer=bilibili_dot_dynamic_dot_common_dot_dynamic__pb2.AtListRsp.FromString,
                )
        self.AtSearch = channel.unary_unary(
                '/bilibili.main.dynamic.feed.v1.Feed/AtSearch',
                request_serializer=bilibili_dot_dynamic_dot_common_dot_dynamic__pb2.AtSearchReq.SerializeToString,
                response_deserializer=bilibili_dot_dynamic_dot_common_dot_dynamic__pb2.AtListRsp.FromString,
                )
        self.ReserveButtonClick = channel.unary_unary(
                '/bilibili.main.dynamic.feed.v1.Feed/ReserveButtonClick',
                request_serializer=bilibili_dot_dynamic_dot_interfaces_dot_feed_dot_v1_dot_api__pb2.ReserveButtonClickReq.SerializeToString,
                response_deserializer=bilibili_dot_dynamic_dot_interfaces_dot_feed_dot_v1_dot_api__pb2.ReserveButtonClickResp.FromString,
                )
        self.CreatePlusButtonClick = channel.unary_unary(
                '/bilibili.main.dynamic.feed.v1.Feed/CreatePlusButtonClick',
                request_serializer=bilibili_dot_dynamic_dot_interfaces_dot_feed_dot_v1_dot_api__pb2.CreatePlusButtonClickReq.SerializeToString,
                response_deserializer=bilibili_dot_dynamic_dot_interfaces_dot_feed_dot_v1_dot_api__pb2.CreatePlusButtonClickRsp.FromString,
                )
        self.HotSearch = channel.unary_unary(
                '/bilibili.main.dynamic.feed.v1.Feed/HotSearch',
                request_serializer=bilibili_dot_dynamic_dot_interfaces_dot_feed_dot_v1_dot_api__pb2.HotSearchReq.SerializeToString,
                response_deserializer=bilibili_dot_dynamic_dot_interfaces_dot_feed_dot_v1_dot_api__pb2.HotSearchRsp.FromString,
                )
        self.Suggest = channel.unary_unary(
                '/bilibili.main.dynamic.feed.v1.Feed/Suggest',
                request_serializer=bilibili_dot_dynamic_dot_interfaces_dot_feed_dot_v1_dot_api__pb2.SuggestReq.SerializeToString,
                response_deserializer=bilibili_dot_dynamic_dot_interfaces_dot_feed_dot_v1_dot_api__pb2.SuggestRsp.FromString,
                )
        self.DynamicButtonClick = channel.unary_unary(
                '/bilibili.main.dynamic.feed.v1.Feed/DynamicButtonClick',
                request_serializer=bilibili_dot_dynamic_dot_interfaces_dot_feed_dot_v1_dot_api__pb2.DynamicButtonClickReq.SerializeToString,
                response_deserializer=bilibili_dot_dynamic_dot_interfaces_dot_feed_dot_v1_dot_api__pb2.DynamicButtonClickRsp.FromString,
                )
        self.CreatePermissionButtonClick = channel.unary_unary(
                '/bilibili.main.dynamic.feed.v1.Feed/CreatePermissionButtonClick',
                request_serializer=bilibili_dot_dynamic_dot_interfaces_dot_feed_dot_v1_dot_api__pb2.CreatePermissionButtonClickReq.SerializeToString,
                response_deserializer=bilibili_dot_dynamic_dot_interfaces_dot_feed_dot_v1_dot_api__pb2.CreatePermissionButtonClickRsp.FromString,
                )
        self.CreatePageInfos = channel.unary_unary(
                '/bilibili.main.dynamic.feed.v1.Feed/CreatePageInfos',
                request_serializer=bilibili_dot_dynamic_dot_interfaces_dot_feed_dot_v1_dot_api__pb2.CreatePageInfosReq.SerializeToString,
                response_deserializer=bilibili_dot_dynamic_dot_interfaces_dot_feed_dot_v1_dot_api__pb2.CreatePageInfosRsp.FromString,
                )


class FeedServicer(object):
    """
    """

    def CreateInitCheck(self, request, context):
        """发布页预校验
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SubmitCheck(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateDyn(self, request, context):
        """创建动态
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetUidByName(self, request, context):
        """根据name取uid
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AtList(self, request, context):
        """at用户推荐列表
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AtSearch(self, request, context):
        """at用户搜索列表
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ReserveButtonClick(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreatePlusButtonClick(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def HotSearch(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Suggest(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DynamicButtonClick(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreatePermissionButtonClick(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreatePageInfos(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_FeedServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateInitCheck': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateInitCheck,
                    request_deserializer=bilibili_dot_dynamic_dot_interfaces_dot_feed_dot_v1_dot_api__pb2.CreateInitCheckReq.FromString,
                    response_serializer=bilibili_dot_dynamic_dot_common_dot_dynamic__pb2.CreateCheckResp.SerializeToString,
            ),
            'SubmitCheck': grpc.unary_unary_rpc_method_handler(
                    servicer.SubmitCheck,
                    request_deserializer=bilibili_dot_dynamic_dot_interfaces_dot_feed_dot_v1_dot_api__pb2.SubmitCheckReq.FromString,
                    response_serializer=bilibili_dot_dynamic_dot_interfaces_dot_feed_dot_v1_dot_api__pb2.SubmitCheckRsp.SerializeToString,
            ),
            'CreateDyn': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateDyn,
                    request_deserializer=bilibili_dot_dynamic_dot_interfaces_dot_feed_dot_v1_dot_api__pb2.CreateDynReq.FromString,
                    response_serializer=bilibili_dot_dynamic_dot_common_dot_dynamic__pb2.CreateResp.SerializeToString,
            ),
            'GetUidByName': grpc.unary_unary_rpc_method_handler(
                    servicer.GetUidByName,
                    request_deserializer=bilibili_dot_dynamic_dot_common_dot_dynamic__pb2.GetUidByNameReq.FromString,
                    response_serializer=bilibili_dot_dynamic_dot_common_dot_dynamic__pb2.GetUidByNameRsp.SerializeToString,
            ),
            'AtList': grpc.unary_unary_rpc_method_handler(
                    servicer.AtList,
                    request_deserializer=bilibili_dot_dynamic_dot_common_dot_dynamic__pb2.AtListReq.FromString,
                    response_serializer=bilibili_dot_dynamic_dot_common_dot_dynamic__pb2.AtListRsp.SerializeToString,
            ),
            'AtSearch': grpc.unary_unary_rpc_method_handler(
                    servicer.AtSearch,
                    request_deserializer=bilibili_dot_dynamic_dot_common_dot_dynamic__pb2.AtSearchReq.FromString,
                    response_serializer=bilibili_dot_dynamic_dot_common_dot_dynamic__pb2.AtListRsp.SerializeToString,
            ),
            'ReserveButtonClick': grpc.unary_unary_rpc_method_handler(
                    servicer.ReserveButtonClick,
                    request_deserializer=bilibili_dot_dynamic_dot_interfaces_dot_feed_dot_v1_dot_api__pb2.ReserveButtonClickReq.FromString,
                    response_serializer=bilibili_dot_dynamic_dot_interfaces_dot_feed_dot_v1_dot_api__pb2.ReserveButtonClickResp.SerializeToString,
            ),
            'CreatePlusButtonClick': grpc.unary_unary_rpc_method_handler(
                    servicer.CreatePlusButtonClick,
                    request_deserializer=bilibili_dot_dynamic_dot_interfaces_dot_feed_dot_v1_dot_api__pb2.CreatePlusButtonClickReq.FromString,
                    response_serializer=bilibili_dot_dynamic_dot_interfaces_dot_feed_dot_v1_dot_api__pb2.CreatePlusButtonClickRsp.SerializeToString,
            ),
            'HotSearch': grpc.unary_unary_rpc_method_handler(
                    servicer.HotSearch,
                    request_deserializer=bilibili_dot_dynamic_dot_interfaces_dot_feed_dot_v1_dot_api__pb2.HotSearchReq.FromString,
                    response_serializer=bilibili_dot_dynamic_dot_interfaces_dot_feed_dot_v1_dot_api__pb2.HotSearchRsp.SerializeToString,
            ),
            'Suggest': grpc.unary_unary_rpc_method_handler(
                    servicer.Suggest,
                    request_deserializer=bilibili_dot_dynamic_dot_interfaces_dot_feed_dot_v1_dot_api__pb2.SuggestReq.FromString,
                    response_serializer=bilibili_dot_dynamic_dot_interfaces_dot_feed_dot_v1_dot_api__pb2.SuggestRsp.SerializeToString,
            ),
            'DynamicButtonClick': grpc.unary_unary_rpc_method_handler(
                    servicer.DynamicButtonClick,
                    request_deserializer=bilibili_dot_dynamic_dot_interfaces_dot_feed_dot_v1_dot_api__pb2.DynamicButtonClickReq.FromString,
                    response_serializer=bilibili_dot_dynamic_dot_interfaces_dot_feed_dot_v1_dot_api__pb2.DynamicButtonClickRsp.SerializeToString,
            ),
            'CreatePermissionButtonClick': grpc.unary_unary_rpc_method_handler(
                    servicer.CreatePermissionButtonClick,
                    request_deserializer=bilibili_dot_dynamic_dot_interfaces_dot_feed_dot_v1_dot_api__pb2.CreatePermissionButtonClickReq.FromString,
                    response_serializer=bilibili_dot_dynamic_dot_interfaces_dot_feed_dot_v1_dot_api__pb2.CreatePermissionButtonClickRsp.SerializeToString,
            ),
            'CreatePageInfos': grpc.unary_unary_rpc_method_handler(
                    servicer.CreatePageInfos,
                    request_deserializer=bilibili_dot_dynamic_dot_interfaces_dot_feed_dot_v1_dot_api__pb2.CreatePageInfosReq.FromString,
                    response_serializer=bilibili_dot_dynamic_dot_interfaces_dot_feed_dot_v1_dot_api__pb2.CreatePageInfosRsp.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'bilibili.main.dynamic.feed.v1.Feed', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Feed(object):
    """
    """

    @staticmethod
    def CreateInitCheck(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.main.dynamic.feed.v1.Feed/CreateInitCheck',
            bilibili_dot_dynamic_dot_interfaces_dot_feed_dot_v1_dot_api__pb2.CreateInitCheckReq.SerializeToString,
            bilibili_dot_dynamic_dot_common_dot_dynamic__pb2.CreateCheckResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SubmitCheck(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.main.dynamic.feed.v1.Feed/SubmitCheck',
            bilibili_dot_dynamic_dot_interfaces_dot_feed_dot_v1_dot_api__pb2.SubmitCheckReq.SerializeToString,
            bilibili_dot_dynamic_dot_interfaces_dot_feed_dot_v1_dot_api__pb2.SubmitCheckRsp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateDyn(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.main.dynamic.feed.v1.Feed/CreateDyn',
            bilibili_dot_dynamic_dot_interfaces_dot_feed_dot_v1_dot_api__pb2.CreateDynReq.SerializeToString,
            bilibili_dot_dynamic_dot_common_dot_dynamic__pb2.CreateResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetUidByName(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.main.dynamic.feed.v1.Feed/GetUidByName',
            bilibili_dot_dynamic_dot_common_dot_dynamic__pb2.GetUidByNameReq.SerializeToString,
            bilibili_dot_dynamic_dot_common_dot_dynamic__pb2.GetUidByNameRsp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AtList(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.main.dynamic.feed.v1.Feed/AtList',
            bilibili_dot_dynamic_dot_common_dot_dynamic__pb2.AtListReq.SerializeToString,
            bilibili_dot_dynamic_dot_common_dot_dynamic__pb2.AtListRsp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AtSearch(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.main.dynamic.feed.v1.Feed/AtSearch',
            bilibili_dot_dynamic_dot_common_dot_dynamic__pb2.AtSearchReq.SerializeToString,
            bilibili_dot_dynamic_dot_common_dot_dynamic__pb2.AtListRsp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ReserveButtonClick(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.main.dynamic.feed.v1.Feed/ReserveButtonClick',
            bilibili_dot_dynamic_dot_interfaces_dot_feed_dot_v1_dot_api__pb2.ReserveButtonClickReq.SerializeToString,
            bilibili_dot_dynamic_dot_interfaces_dot_feed_dot_v1_dot_api__pb2.ReserveButtonClickResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreatePlusButtonClick(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.main.dynamic.feed.v1.Feed/CreatePlusButtonClick',
            bilibili_dot_dynamic_dot_interfaces_dot_feed_dot_v1_dot_api__pb2.CreatePlusButtonClickReq.SerializeToString,
            bilibili_dot_dynamic_dot_interfaces_dot_feed_dot_v1_dot_api__pb2.CreatePlusButtonClickRsp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def HotSearch(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.main.dynamic.feed.v1.Feed/HotSearch',
            bilibili_dot_dynamic_dot_interfaces_dot_feed_dot_v1_dot_api__pb2.HotSearchReq.SerializeToString,
            bilibili_dot_dynamic_dot_interfaces_dot_feed_dot_v1_dot_api__pb2.HotSearchRsp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Suggest(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.main.dynamic.feed.v1.Feed/Suggest',
            bilibili_dot_dynamic_dot_interfaces_dot_feed_dot_v1_dot_api__pb2.SuggestReq.SerializeToString,
            bilibili_dot_dynamic_dot_interfaces_dot_feed_dot_v1_dot_api__pb2.SuggestRsp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DynamicButtonClick(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.main.dynamic.feed.v1.Feed/DynamicButtonClick',
            bilibili_dot_dynamic_dot_interfaces_dot_feed_dot_v1_dot_api__pb2.DynamicButtonClickReq.SerializeToString,
            bilibili_dot_dynamic_dot_interfaces_dot_feed_dot_v1_dot_api__pb2.DynamicButtonClickRsp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreatePermissionButtonClick(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.main.dynamic.feed.v1.Feed/CreatePermissionButtonClick',
            bilibili_dot_dynamic_dot_interfaces_dot_feed_dot_v1_dot_api__pb2.CreatePermissionButtonClickReq.SerializeToString,
            bilibili_dot_dynamic_dot_interfaces_dot_feed_dot_v1_dot_api__pb2.CreatePermissionButtonClickRsp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreatePageInfos(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.main.dynamic.feed.v1.Feed/CreatePageInfos',
            bilibili_dot_dynamic_dot_interfaces_dot_feed_dot_v1_dot_api__pb2.CreatePageInfosReq.SerializeToString,
            bilibili_dot_dynamic_dot_interfaces_dot_feed_dot_v1_dot_api__pb2.CreatePageInfosRsp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
